@@ -15,10 +15,8 @@ import os
 import sys
 import time
 import types
-
-from six import class_types
-from six.moves._thread import get_ident
-from six.moves.urllib import parse
+from _thread import get_ident
+from urllib import parse
 
 from AccessControl.class_init import InitializeClass
 from AccessControl.requestmethod import requestmethod
@@ -36,7 +34,7 @@ from Persistence import Persistent
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
 
-class FakeConnection(object):
+class FakeConnection:
     # Supports the methods of Connection that CacheManager needs
 
     def __init__(self, db, parent_jar):
@@ -164,7 +162,7 @@ class DebugManager(Tabs, Traversable, Implicit):
         {'label': 'Debug Information', 'action': 'manage_main'},
     )
 
-    def refcount(self, n=None, t=(type(Implicit),) + class_types):
+    def refcount(self, n=None, t=(type(Implicit), type(object))):
         # return class reference info
         counts = {}
         for m in list(sys.modules.values()):
@@ -180,7 +178,7 @@ class DebugManager(Tabs, Traversable, Implicit):
         for ob, v in counts.items():
             ob_name = getattr(ob, "__name__", "unknown")
             if hasattr(ob, '__module__'):
-                name = '%s.%s' % (ob.__module__, ob_name)
+                name = f'{ob.__module__}.{ob_name}'
             else:
                 name = '%s' % ob_name
             pairs.append((v, name))
@@ -292,7 +290,7 @@ class ApplicationManager(CacheManager,
         h = h and ('%d hour%s' % (h, (h != 1 and 's' or ''))) or ''
         m = m and ('%d min' % m) or ''
         s = '%d sec' % s
-        return '%s %s %s %s' % (d, h, m, s)
+        return f'{d} {h} {m} {s}'
 
     def sys_version(self):
         return sys.version
@@ -368,8 +366,7 @@ class AltDatabaseManager(Traversable, UndoSupport):
 
         if REQUEST is not None:
             msg = 'ZODB in-memory caches minimized.'
-            url = '%s/manage_main?manage_tabs_message=%s' % (REQUEST['URL1'],
-                                                             msg)
+            url = f'{REQUEST["URL1"]}/manage_main?manage_tabs_message={msg}'
             REQUEST.RESPONSE.redirect(url)
 
     @requestmethod('POST')
@@ -390,8 +387,7 @@ class AltDatabaseManager(Traversable, UndoSupport):
             msg = 'Invalid days value %s' % str(days)
 
         if REQUEST is not None:
-            url = '%s/manage_main?manage_tabs_message=%s' % (REQUEST['URL1'],
-                                                             msg)
+            url = f'{REQUEST["URL1"]}/manage_main?manage_tabs_message={msg}'
             REQUEST['RESPONSE'].redirect(url)
 
         return t
