@@ -13,6 +13,7 @@
 """Copy interface
 """
 
+import base64
 import logging
 import re
 import tempfile
@@ -22,8 +23,6 @@ from json import loads
 from zlib import compress
 from zlib import decompressobj
 
-import six
-
 import transaction
 from AccessControl import ClassSecurityInfo
 from AccessControl import getSecurityManager
@@ -54,14 +53,6 @@ from zope.lifecycleevent import ObjectCopiedEvent
 from zope.lifecycleevent import ObjectMovedEvent
 
 
-try:
-    from base64 import decodebytes
-    from base64 import encodebytes
-except ImportError:  # Python 2
-    from base64 import decodestring as decodebytes
-    from base64 import encodestring as encodebytes
-
-
 class CopyError(Exception):
     pass
 
@@ -169,7 +160,7 @@ class CopyContainer(Base):
         while 1:
             if self._getOb(id, None) is None:
                 return id
-            id = 'copy%s_of_%s' % (n and n + 1 or '', orig_id)
+            id = 'copy{}_of_{}'.format(n and n + 1 or '', orig_id)
             n = n + 1
 
     def _pasteObjects(self, cp, cb_maxsize=0):
@@ -196,7 +187,7 @@ class CopyContainer(Base):
         try:
             op, mdatas = _cb_decode(cp, cb_maxsize)
         except Exception as e:
-            six.raise_from(CopyError('Clipboard Error'), e)
+            raise CopyError('Clipboard Error') from e
 
         oblist = []
         app = self.getPhysicalRoot()
@@ -677,7 +668,7 @@ def _cb_encode(d):
     json_bytes = dumps(d).encode('utf-8')
     squashed_bytes = compress(json_bytes, 2)  # -> bytes w/ useful encoding
     # quote for embeding in cookie
-    return encodebytes(squashed_bytes)
+    return base64.encodebytes(squashed_bytes)
 
 
 def _cb_decode(s, maxsize=8192):
@@ -689,9 +680,9 @@ def _cb_decode(s, maxsize=8192):
     Return a list of text IDs.
     """
     dec = decompressobj()
-    if six.PY3 and isinstance(s, str):
+    if isinstance(s, str):
         s = s.encode('latin-1')
-    data = dec.decompress(decodebytes(s), maxsize)
+    data = dec.decompress(base64.decodebytes(s), maxsize)
     if dec.unconsumed_tail:
         raise ValueError
     json_bytes = data.decode('utf-8')
