@@ -13,18 +13,11 @@
 """DTML Method objects.
 """
 import re
-from warnings import warn
-
-from six import PY2
-from six import PY3
-from six import binary_type
-from six import text_type
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
 
 from AccessControl import getSecurityManager
 from AccessControl.class_init import InitializeClass
 from AccessControl.Permissions import change_proxy_roles  # NOQA
-from AccessControl.Permissions import ftp_access
 from AccessControl.Permissions import view as View
 from AccessControl.Permissions import view_management_screens
 from AccessControl.requestmethod import requestmethod
@@ -36,7 +29,6 @@ from App.special_dtml import DTMLFile
 from DocumentTemplate.DT_Util import ParseError
 from DocumentTemplate.permissions import change_dtml_methods
 from DocumentTemplate.security import RestrictedDTML
-from OFS import bbb
 from OFS.Cache import Cacheable
 from OFS.History import Historical
 from OFS.History import html_diff
@@ -54,7 +46,7 @@ from ZPublisher.Iterators import IStreamIterator
 _marker = []  # Create a new marker object.
 
 
-class Code(object):
+class Code:
     # Documents masquerade as functions:
     pass
 
@@ -193,9 +185,6 @@ class DTMLMethod(
                 c = self.content_type
             else:
                 encoding = getattr(self, 'encoding', default_encoding)
-                if PY2 and not isinstance(r, text_type):
-                    # Prevent double-encoding edge cases under Python 2
-                    r = r.decode(encoding)
                 c, e = guess_content_type(self.getId(), r.encode(encoding))
             RESPONSE.setHeader('Content-Type', c)
         result = decapitate(r, RESPONSE)
@@ -397,19 +386,10 @@ class DTMLMethod(
             self, rev1, rev2, REQUEST,
             historyComparisonResults=html_diff(rev1.read(), rev2.read()))
 
-    if bbb.HAS_ZSERVER:
-
-        @security.protected(ftp_access)
-        def manage_FTPget(self):
-            """ Get source for FTP download.
-            """
-            warn(u'manage_FTPget is deprecated and will be removed in Zope 5.',
-                 DeprecationWarning, stacklevel=2)
-            return self.read()
-
 
 InitializeClass(DTMLMethod)
 
+
 token = r"[a-zA-Z0-9!#$%&'*+\-.\\\\^_`|~]+"
 hdr_start = re.compile(r'(%s):(.*)' % token).match
 
@@ -453,10 +433,8 @@ def safe_file_data(data):
     # Helper to convert upload file content into a safe value for saving
     if hasattr(data, 'read'):
         data = data.read()
-    if PY3 and isinstance(data, binary_type):
+    if isinstance(data, bytes):
         data = data.decode('utf-8')
-    if PY2 and isinstance(data, text_type):
-        data = data.encode('utf-8')
     return data
 
 
@@ -497,6 +475,6 @@ def addDTMLMethod(self, id, title='', file='', REQUEST=None, submit=None):
         except Exception:
             u = REQUEST['URL1']
         if submit == "Add and Edit":
-            u = "%s/%s" % (u, quote(id))
+            u = f"{u}/{quote(id)}"
         REQUEST.RESPONSE.redirect(u + '/manage_main')
     return ''
