@@ -13,21 +13,13 @@
 """Object Manager
 """
 
-import copy
-import fnmatch
-import marshal
+import html
 import os
 import re
-import sys
-import time
 from io import BytesIO
 from logging import getLogger
 from operator import itemgetter
-from warnings import warn
-
-from six import string_types
-from six import text_type
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
 
 import zope.sequencesort
 from AccessControl import ClassSecurityInfo
@@ -39,12 +31,10 @@ from AccessControl.Permissions import delete_objects
 from AccessControl.Permissions import ftp_access
 from AccessControl.Permissions import import_export_objects
 from AccessControl.Permissions import view_management_screens
-from AccessControl.ZopeSecurityPolicy import getRoles
 from Acquisition import Implicit
 from Acquisition import aq_acquire
 from Acquisition import aq_base
 from Acquisition import aq_parent
-from App.Common import is_acquired
 from App.config import getConfiguration
 from App.FactoryDispatcher import ProductDispatcher
 from App.Management import Navigation
@@ -52,7 +42,6 @@ from App.Management import Tabs
 from App.special_dtml import DTMLFile
 from DateTime import DateTime
 from DateTime.interfaces import DateTimeError
-from OFS import bbb
 from OFS.CopySupport import CopyContainer
 from OFS.event import ObjectWillBeAddedEvent
 from OFS.event import ObjectWillBeRemovedEvent
@@ -72,12 +61,7 @@ from zope.interface import implementer
 from zope.interface.interfaces import ComponentLookupError
 from zope.lifecycleevent import ObjectAddedEvent
 from zope.lifecycleevent import ObjectRemovedEvent
-
-
-try:
-    from html import escape
-except ImportError:  # PY2
-    from cgi import escape
+from ZPublisher.HTTPResponse import make_content_disposition
 
 
 # Constants: __replaceable__ flags:
@@ -104,13 +88,13 @@ def checkValidId(self, id, allow_dup=0):
     # check_valid_id() will be called again later with allow_dup
     # set to false before the object is added.
     if not id or not isinstance(id, str):
-        if isinstance(id, text_type):
-            id = escape(id, True)
+        if isinstance(id, str):
+            id = html.escape(id, True)
         raise BadRequest('Empty or invalid id specified', id)
     if bad_id(id) is not None:
         raise BadRequest(
-            ('The id "%s" contains characters '
-             'illegal in URLs.' % escape(id, True)))
+            'The id "%s" contains characters '
+            'illegal in URLs.' % html.escape(id, True))
     if id in ('.', '..'):
         raise BadRequest(
             'The id "%s" is invalid because it is not traversable.' % id)
@@ -546,7 +530,7 @@ class ObjectManager(
 
         The objects specified in 'ids' get deleted.
         """
-        if isinstance(ids, string_types):
+        if isinstance(ids, str):
             ids = [ids]
         if not ids:
             raise BadRequest('No items specified')
@@ -569,7 +553,8 @@ class ObjectManager(
                 pass
 
             if v is self:
-                raise BadRequest('%s does not exist' % escape(ids[-1], True))
+                raise BadRequest('%s does not exist' %
+                                 html.escape(ids[-1], True))
             self._delObject(id)
             del ids[-1]
         if REQUEST is not None:
@@ -627,21 +612,20 @@ class ObjectManager(
 
             if RESPONSE is not None:
                 RESPONSE.setHeader('Content-type', 'application/data')
-                RESPONSE.setHeader('Content-Disposition',
-                                   'inline;filename=%s.%s' % (id, suffix))
+                RESPONSE.setHeader(
+                    'Content-Disposition',
+                    make_content_disposition('inline', f'{id}.{suffix}')
+                )
             return result
 
-        f = os.path.join(CONFIG.clienthome, '%s.%s' % (id, suffix))
+        f = os.path.join(CONFIG.clienthome, f'{id}.{suffix}')
         with open(f, 'w+b') as fd:
             ob._p_jar.exportFile(ob._p_oid, fd)
 
         if REQUEST is not None:
             return self.manage_main(
                 self, REQUEST,
-                manage_tabs_message='"%s" successfully exported to "%s"' % (
-                    id,
-                    f
-                ),
+                manage_tabs_message=f'"{id}" successfully exported to "{f}"',
                 title='Object exported'
             )
 
@@ -654,14 +638,17 @@ class ObjectManager(
         """Import an object from a file"""
         dirname, file = os.path.split(file)
         if dirname:
-            raise BadRequest('Invalid file name %s' % escape(file, True))
+            raise BadRequest('Invalid file name %s' % html.escape(file, True))
 
         for impath in self._getImportPaths():
             filepath = os.path.join(impath, 'import', file)
             if os.path.exists(filepath):
                 break
         else:
-            raise BadRequest('File does not exist: %s' % escape(file, True))
+            raise BadRequest(
+                'File does not exist: %s' %
+                html.escape(
+                    file, True))
 
         imported = self._importObjectFromFile(
             filepath, verify=bool(REQUEST), set_owner=set_owner,
@@ -727,105 +714,17 @@ class ObjectManager(
     @security.protected(ftp_access)
     def manage_hasId(self, REQUEST):
         """Check if the folder has an object with REQUEST['id']."""
-
+        # When this method will be removed, please also remove
+        # `ftp_access` both from `AppendixA`from the Zope Developers
+        # Book and from `AccessControl.Permissions`
+        import warnings
+        warnings.warn(
+            "`ObjectManager.manage_hasId` is deprecated "
+            "and will be removed in future.",
+            DeprecationWarning)
         if not REQUEST['id'] in self.objectIds():
             raise KeyError(REQUEST['id'])
 
-    if bbb.HAS_ZSERVER:
-        # FTP support methods
-
-        @security.protected(ftp_access)
-        def manage_FTPlist(self, REQUEST):
-            """Directory listing for FTP.
-            """
-            warn(u'manage_FTPlist is deprecated and will be removed in '
-                 u'Zope 5.', DeprecationWarning, stacklevel=2)
-            out = ()
-
-            # check to see if we are being acquiring or not
-            ob = self
-            while 1:
-                if is_acquired(ob):
-                    raise ValueError(
-                        'FTP List not supported on acquired objects')
-                if not hasattr(ob, '__parent__'):
-                    break
-                ob = aq_parent(ob)
-
-            files = list(self.objectItems())
-
-            # recursive ride through all subfolders (ls -R) (ajung)
-
-            if REQUEST.environ.get('FTP_RECURSIVE', 0) == 1:
-                all_files = copy.copy(files)
-                for f in files:
-                    if hasattr(aq_base(f[1]), 'isPrincipiaFolderish') and \
-                       f[1].isPrincipiaFolderish:
-                        all_files.extend(findChildren(f[1]))
-                files = all_files
-
-            # Perform globbing on list of files (ajung)
-
-            globbing = REQUEST.environ.get('GLOBBING', '')
-            if globbing:
-                files = [x for x in files if fnmatch.fnmatch(x[0], globbing)]
-
-            files.sort()
-
-            if not (hasattr(self, 'isTopLevelPrincipiaApplicationObject')
-                    and self.isTopLevelPrincipiaApplicationObject):
-                files.insert(0, ('..', aq_parent(self)))
-            files.insert(0, ('.', self))
-            for k, v in files:
-                # Note that we have to tolerate failure here, because
-                # Broken objects won't stat correctly. If an object fails
-                # to be able to stat itself, we will ignore it, but log
-                # the error.
-                try:
-                    stat = marshal.loads(v.manage_FTPstat(REQUEST))
-                except Exception:
-                    LOG.error("Failed to stat file '%s'" % k,
-                              exc_info=sys.exc_info())
-                    stat = None
-                if stat is not None:
-                    out = out + ((k, stat),)
-            return marshal.dumps(out)
-
-        @security.protected(ftp_access)
-        def manage_FTPstat(self, REQUEST):
-            """Psuedo stat, used by FTP for directory listings.
-            """
-            warn(u'manage_FTPstat is deprecated and will be removed in '
-                 u'Zope 5.', DeprecationWarning, stacklevel=2)
-            mode = 0o0040000
-            from AccessControl.User import nobody
-            # check to see if we are acquiring our objectValues or not
-            parents = REQUEST.PARENTS
-            if not (len(parents) > 1
-                    and self.objectValues() == parents[1].objectValues()):
-                try:
-                    if getSecurityManager().validate(
-                            None, self, 'manage_FTPlist', self.manage_FTPlist):
-                        mode = mode | 0o0770
-                except Exception:
-                    pass
-
-                if nobody.allowed(self, getRoles(
-                        self, 'manage_FTPlist', self.manage_FTPlist, ())):
-                    mode = mode | 0o0007
-            if hasattr(aq_base(self), '_p_mtime'):
-                mtime = DateTime(self._p_mtime).timeTime()
-            else:
-                mtime = time.time()
-            # get owner and group
-            owner = group = 'Zope'
-            for user, roles in self.get_local_roles():
-                if 'Owner' in roles:
-                    owner = user
-                    break
-            return marshal.dumps(
-                (mode, 0, 0, 1, owner, group, 0, mtime, mtime, mtime))
-
     def __delitem__(self, name):
         return self.manage_delObjects(ids=[name])
 
@@ -857,10 +756,6 @@ class ObjectManager(
     def __len__(self):
         return len(self.objectIds())
 
-    def __nonzero__(self):
-        # Py2
-        return self.__bool__()
-
     def __bool__(self):
         return True
 
@@ -884,7 +779,7 @@ class ObjectManager(
 
     @security.protected(access_contents_information)
     def compute_size(self, ob):
-        if hasattr(aq_base(ob), 'get_size'):
+        if hasattr(ob, 'get_size'):
             ob_size = ob.get_size()
             if ob_size < 1024:
                 return '1 KiB'
@@ -976,7 +871,7 @@ def findChildren(obj, dirname=''):
     return lst
 
 
-class IFAwareObjectManager(object):
+class IFAwareObjectManager:
 
     def all_meta_types(self, interfaces=None):
 
