@@ -12,8 +12,7 @@
 #
 ##############################################################################
 
-from six.moves.urllib.parse import quote
-from six.moves.urllib.parse import unquote
+from urllib.parse import quote
 
 from Acquisition import aq_parent
 from OFS.interfaces import ITraversable
@@ -35,9 +34,6 @@ class AbsoluteURL(BrowserView):
     all the methods that it uses yet.
     """
 
-    def __unicode__(self):
-        return unquote(self.__str__()).decode('utf-8')
-
     def __str__(self):
         context = self.context
         request = self.request
@@ -80,11 +76,11 @@ class AbsoluteURL(BrowserView):
             raise TypeError(_insufficientContext)
 
         if name:
+            url = "{}/{}".format(
+                base[-1]['url'],
+                quote(name.encode('utf-8'), _safe))
             base += ({'name': name,
-                      'url': ("%s/%s" % (base[-1]['url'],
-                                         quote(name.encode('utf-8'), _safe)))
-                      }, )
-
+                      'url': url}, )
         return base
 
 
@@ -93,9 +89,6 @@ class OFSTraversableAbsoluteURL(BrowserView):
     """An absolute_url adapter for OFS.Traversable subclasses
     """
 
-    def __unicode__(self):
-        return unquote(self.__str__()).decode('utf-8')
-
     def __str__(self):
         return self.context.absolute_url()
 
@@ -115,8 +108,8 @@ class OFSTraversableAbsoluteURL(BrowserView):
 
         view = getMultiAdapter((container, request), IAbsoluteURL)
         base = tuple(view.breadcrumbs())
-        base += (
-            {'name': name, 'url': ("%s/%s" % (base[-1]['url'], name))},)
+        base += ({'name': name,
+                  'url': "{}/{}".format(base[-1]['url'], name)},)
 
         return base
 
