@@ -1,19 +1,16 @@
-# -*- coding: utf-8 -*-
 import os
 import sys
 import time
 import unittest
 from io import BytesIO
 
-import six
-from six import PY3
-
 import OFS.Image
 import Testing.testbrowser
 import Testing.ZopeTestCase
 import transaction
 import Zope2
 from Acquisition import aq_base
+from App.Common import rfc1123_date
 from OFS.Application import Application
 from OFS.Cache import ZCM_MANAGERS
 from OFS.Image import Pdata
@@ -21,7 +18,6 @@ from OFS.SimpleItem import SimpleItem
 from Testing.makerequest import makerequest
 from zExceptions import Redirect
 from zope.component import adapter
-from zope.datetime import rfc1123_date
 from zope.lifecycleevent.interfaces import IObjectCreatedEvent
 from zope.lifecycleevent.interfaces import IObjectModifiedEvent
 from ZPublisher.HTTPRequest import HTTPRequest
@@ -53,7 +49,7 @@ def aputrequest(file, content_type):
     return req
 
 
-class DummyCache(object):
+class DummyCache:
 
     def __init__(self):
         self.clear()
@@ -89,7 +85,7 @@ class DummyCacheManager(SimpleItem):
         return ADummyCache
 
 
-class EventCatcher(object):
+class EventCatcher:
 
     def __init__(self):
         self.created = []
@@ -292,8 +288,7 @@ class FileTests(unittest.TestCase):
 
     def testPrincipiaSearchSource_not_text(self):
         data = ''.join([chr(x) for x in range(256)])
-        if PY3:
-            data = data.encode('utf-8')
+        data = data.encode('utf-8')
         self.file.manage_edit('foobar', 'application/octet-stream',
                               filedata=data)
         self.assertEqual(self.file.PrincipiaSearchSource(), b'')
@@ -323,12 +318,12 @@ class FileTests(unittest.TestCase):
         verifyClass(IWriteLock, File)
 
     def testUnicode(self):
-        val = u'some unicode string here'
+        val = 'some unicode string here'
 
         self.assertRaises(TypeError, self.file.update_data,
                           data=val, content_type='text/plain')
 
-    def testStr(self):
+    def test__str__returns_native_string(self):
         small_data = b'small data'
         self.file.manage_upload(file=small_data)
         self.assertEqual(str(self.file), small_data.decode())
@@ -363,12 +358,21 @@ class ImageTests(FileTests):
 
     testStr = testTag
 
+    def test__str__returns_native_string(self):
+        small_data = b'small data'
+        self.file.manage_upload(file=small_data)
+        self.assertIsInstance(str(self.file), str)
+
+        # Make sure Pdata contents are handled correctly
+        big_data = b'a' * (2 << 16)
+        self.file.manage_upload(file=big_data)
+        self.assertIsInstance(str(self.file), str)
+
     def testViewImageOrFile(self):
         request = self.app.REQUEST
         response = request.RESPONSE
         result = self.file.index_html(request, response)
         self.assertEqual(result, self.data)
-        self.assertIsNone(response.getHeader("Content-Disposition"))
 
     def test_interfaces(self):
         from OFS.Image import Image
@@ -378,71 +382,16 @@ class ImageTests(FileTests):
         verifyClass(IWriteLock, Image)
 
     def test_text_representation_is_tag(self):
-        self.assertEqual(six.text_type(self.file),
+        self.assertEqual(str(self.file),
                          '<img src="http://nohost/file"'
                          ' alt="" title="" height="16" width="16" />')
 
 
-class SVGTests(ImageTests):
-    content_type = 'image/svg+xml'
-
-    def testViewImageOrFile(self):
-        request = self.app.REQUEST
-        response = request.RESPONSE
-        result = self.file.index_html(request, response)
-        self.assertEqual(result, self.data)
-        self.assertEqual(
-            response.getHeader("Content-Disposition"),
-            "attachment; filename*=UTF-8''file.svg",
-        )
-
-    def testViewImageOrFileNonAscii(self):
-        try:
-            factory = getattr(self.app, self.factory)
-            factory('hällo',
-                    file=self.data, content_type=self.content_type)
-            transaction.commit()
-        except Exception:
-            transaction.abort()
-            self.connection.close()
-            raise
-        transaction.begin()
-        image = getattr(self.app, 'hällo')
-        request = self.app.REQUEST
-        response = request.RESPONSE
-        result = image.index_html(request, response)
-        self.assertEqual(result, self.data)
-        self.assertEqual(
-            response.getHeader("Content-Disposition"),
-            "attachment; filename*=UTF-8''h%C3%A4llo.svg",
-        )
-
-    def testViewImageOrFile_with_denylist(self):
-        request = self.app.REQUEST
-        response = request.RESPONSE
-        self.file.use_denylist = True
-        result = self.file.index_html(request, response)
-        self.assertEqual(result, self.data)
-        self.assertEqual(
-            response.getHeader("Content-Disposition"),
-            "attachment; filename*=UTF-8''file.svg",
-        )
-
-    def testViewImageOrFile_with_empty_denylist(self):
-        request = self.app.REQUEST
-        response = request.RESPONSE
-        self.file.use_denylist = True
-        self.file.disallowed_inline_mimetypes = []
-        result = self.file.index_html(request, response)
-        self.assertEqual(result, self.data)
-        self.assertIsNone(response.getHeader("Content-Disposition"))
-
-
 class FileEditTests(Testing.ZopeTestCase.FunctionalTestCase):
     """Browser testing ..Image.File"""
 
     def setUp(self):
-        super(FileEditTests, self).setUp()
+        super().setUp()
         uf = self.app.acl_users
         uf.userFolderAddUser('manager', 'manager_pass', ['Manager'], [])
         self.app.manage_addFile('file')
@@ -453,15 +402,14 @@ class FileEditTests(Testing.ZopeTestCase.FunctionalTestCase):
 
     def test_Image__manage_main__1(self):
         """It shows the content of text files as text."""
-        self.app.file.update_data(u'hällo'.encode('utf-8'))
+        self.app.file.update_data('hällo'.encode())
         self.browser.open('http://localhost/file/manage_main')
         text = self.browser.getControl(name='filedata:text').value
         self.assertEqual(text, 'hällo')
 
-    @unittest.skipIf(six.PY2, "feature not supported on Python 2")
     def test_Image__manage_main__3(self):
         """It shows an error message if the file content cannot be decoded."""
-        self.app.file.update_data(u'hällo'.encode('latin-1'))
+        self.app.file.update_data('hällo'.encode('latin-1'))
         self.browser.open('http://localhost/file/manage_main')
         self.assertIn(
             "The file could not be decoded with 'utf-8'.",
@@ -484,7 +432,7 @@ class FileEditTests(Testing.ZopeTestCase.FunctionalTestCase):
         self.browser.open('http://localhost/file/manage_main')
         text_1 = self.browser.getControl(name='filedata:text').value
         self.assertEqual(text_1, '')
-        self.browser.getControl(name='filedata:text').value = u'hällo'
+        self.browser.getControl(name='filedata:text').value = 'hällo'
         self.browser.getControl('Save Changes').click()
         self.assertIn('Saved changes', self.browser.contents)
         text_2 = self.browser.getControl(name='filedata:text').value
