@@ -49,6 +49,7 @@ class TestRequestRange(unittest.TestCase):
     def setUp(self):
         import io
         import string
+
         import transaction
         from OFS.Application import Application
         from OFS.Folder import manage_addFolder
@@ -115,7 +116,7 @@ class TestRequestRange(unittest.TestCase):
         return body + rv
 
     def createLastModifiedDate(self, offset=0):
-        from zope.datetime import rfc1123_date
+        from App.Common import rfc1123_date
         return rfc1123_date(self.file._p_mtime + offset)
 
     def expectUnsatisfiable(self, range):
@@ -168,9 +169,9 @@ class TestRequestRange(unittest.TestCase):
         self.assertEqual(body, self.data[start:end])
 
     def expectMultipleRanges(self, range, sets, draft=0):
+        import email
         import io
         import re
-        import email
         rangeParse = re.compile(r'bytes\s*(\d+)-(\d+)/(\d+)')
         req = self.app.REQUEST
         rsp = req.RESPONSE
@@ -310,7 +311,7 @@ class TestRequestRange(unittest.TestCase):
         length = len(self.data)
         start, end = length - 100, length + 100
         self.expectMultipleRanges(
-            '3-700,%s-%s' % (start, end),
+            f'3-700,{start}-{end}',
             [(3, 701), (len(self.data) - 100, len(self.data))])
 
     # If-Range headers
