@@ -29,7 +29,7 @@ def setUp(test):
     eventtesting.setUp(test)
 
 
-class DontComplain(object):
+class DontComplain:
 
     def _verifyObjectPaste(self, object, validate_src=1):
         pass
@@ -44,21 +44,21 @@ class DontComplain(object):
 class NotifyBase(DontComplain):
 
     def manage_afterAdd(self, item, container):
-        print('old manage_afterAdd %s %s %s' % (
+        print('old manage_afterAdd {} {} {}'.format(
             self.getId(), item.getId(), container.getId()))
-        super(NotifyBase, self).manage_afterAdd(item, container)
+        super().manage_afterAdd(item, container)
 
     manage_afterAdd.__five_method__ = True  # Shut up deprecation warnings
 
     def manage_beforeDelete(self, item, container):
-        super(NotifyBase, self).manage_beforeDelete(item, container)
-        print('old manage_beforeDelete %s %s %s' % (
+        super().manage_beforeDelete(item, container)
+        print('old manage_beforeDelete {} {} {}'.format(
             self.getId(), item.getId(), container.getId()))
     manage_beforeDelete.__five_method__ = True  # Shut up deprecation warnings
 
     def manage_afterClone(self, item):
-        print('old manage_afterClone %s %s' % (self.getId(), item.getId()))
-        super(NotifyBase, self).manage_afterClone(item)
+        print(f'old manage_afterClone {self.getId()} {item.getId()}')
+        super().manage_afterClone(item)
     manage_afterClone.__five_method__ = True  # Shut up deprecation warnings
 
 
