@@ -1,5 +1,6 @@
 import unittest
 
+
 class ViewPageTemplateFileTests(unittest.TestCase):
 
     def setUp(self):
@@ -30,20 +31,18 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         self.assertEqual(vptf.id, 'seagull.pt')
 
     def test_getId_with_path(self):
-        vptf = self._makeOne('pages/dirpage1.pt')
+        vptf = self._makeOne('templates/dirpage1.pt')
         self.assertEqual(vptf.id, 'dirpage1.pt')
 
     def test_pt_getEngine(self):
-        from zope.tales.expressions import DeferExpr
-        from zope.tales.expressions import NotExpr
-        from zope.tales.expressions import PathExpr
-        from zope.tales.expressions import StringExpr
-        from zope.tales.expressions import Undefs
-        from zope.tales.pythonexpr import PythonExpr
-        from zope.contentprovider.tales import TALESProviderExpression
-        from Products.PageTemplates.DeferExpr import LazyExpr
-        from Products.PageTemplates.Expressions import TrustedZopePathExpr
         from Products.PageTemplates.Expressions import SecureModuleImporter
+        from Products.PageTemplates.Expressions import TrustedZopePathExpr
+        from Products.PageTemplates.Expressions import UnicodeAwareStringExpr
+        from zope.contentprovider.tales import TALESProviderExpression
+        from zope.tales.expressions import DeferExpr
+        from zope.tales.expressions import LazyExpr
+        from zope.tales.expressions import NotExpr
+        from zope.tales.pythonexpr import PythonExpr
 
         vptf = self._makeOne('seagull.pt')
         engine = vptf.pt_getEngine()
@@ -51,7 +50,7 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         self.assertEqual(engine.types['path'], TrustedZopePathExpr)
         self.assertEqual(engine.types['exists'], TrustedZopePathExpr)
         self.assertEqual(engine.types['nocall'], TrustedZopePathExpr)
-        self.assertEqual(engine.types['string'], StringExpr)
+        self.assertEqual(engine.types['string'], UnicodeAwareStringExpr)
         self.assertEqual(engine.types['python'], PythonExpr)
         self.assertEqual(engine.types['not'], NotExpr)
         self.assertEqual(engine.types['defer'], DeferExpr)
@@ -60,32 +59,30 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         self.assertEqual(engine.base_names['modules'], SecureModuleImporter)
 
     def test_pt_getContext_no_kw_no_physicalRoot(self):
+        from AccessControl.SecurityManagement import newSecurityManager
         from Products.Five.browser.pagetemplatefile import ViewMapper
         from Products.PageTemplates.Expressions import SecureModuleImporter
-        from AccessControl.SecurityManagement import newSecurityManager
         newSecurityManager(None, DummyUser('a_user'))
         context = DummyContext()
         request = DummyRequest()
         view = self._makeView(context, request)
         vptf = self._makeOne('seagull.pt')
         namespace = vptf.pt_getContext(view, request)
-        self.failUnless(namespace['context'] is context)
-        self.failUnless(namespace['request'] is request)
+        self.assertTrue(namespace['context'] is context)
+        self.assertTrue(namespace['request'] is request)
         views = namespace['views']
-        self.failUnless(isinstance(views, ViewMapper))
+        self.assertIsInstance(views, ViewMapper)
         self.assertEqual(views.ob, context)
         self.assertEqual(views.request, request)
-        self.failUnless(namespace['here'] is context)
-        self.failUnless(namespace['container'] is context)
-        self.failUnless(namespace['root'] is None)
+        self.assertTrue(namespace['here'] is context)
+        self.assertTrue(namespace['container'] is context)
+        self.assertTrue(namespace['root'] is None)
         modules = namespace['modules']
-        self.failUnless(modules is SecureModuleImporter)
+        self.assertTrue(modules is SecureModuleImporter)
         self.assertEqual(namespace['traverse_subpath'], [])
         self.assertEqual(namespace['user'].getId(), 'a_user')
 
     def test_pt_getContext_w_physicalRoot(self):
-        from Products.Five.browser.pagetemplatefile import ViewMapper
-        from Products.PageTemplates.Expressions import SecureModuleImporter
         from AccessControl.SecurityManagement import newSecurityManager
         newSecurityManager(None, DummyUser('a_user'))
         context = DummyContext()
@@ -95,11 +92,9 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         view = self._makeView(context, request)
         vptf = self._makeOne('seagull.pt')
         namespace = vptf.pt_getContext(view, request)
-        self.failUnless(namespace['root'] is root)
+        self.assertTrue(namespace['root'] is root)
 
     def test_pt_getContext_w_ignored_kw(self):
-        from Products.Five.browser.pagetemplatefile import ViewMapper
-        from Products.PageTemplates.Expressions import SecureModuleImporter
         from AccessControl.SecurityManagement import newSecurityManager
         newSecurityManager(None, DummyUser('a_user'))
         context = DummyContext()
@@ -107,12 +102,10 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         view = self._makeView(context, request)
         vptf = self._makeOne('seagull.pt')
         namespace = vptf.pt_getContext(view, request, foo='bar')
-        self.failIf('foo' in namespace)
-        self.failIf('foo' in namespace['options'])
+        self.assertFalse('foo' in namespace)
+        self.assertFalse('foo' in namespace['options'])
 
     def test_pt_getContext_w_args_kw(self):
-        from Products.Five.browser.pagetemplatefile import ViewMapper
-        from Products.PageTemplates.Expressions import SecureModuleImporter
         from AccessControl.SecurityManagement import newSecurityManager
         newSecurityManager(None, DummyUser('a_user'))
         context = DummyContext()
@@ -123,8 +116,6 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         self.assertEqual(namespace['args'], ('bar', 'baz'))
 
     def test_pt_getContext_w_options_kw(self):
-        from Products.Five.browser.pagetemplatefile import ViewMapper
-        from Products.PageTemplates.Expressions import SecureModuleImporter
         from AccessControl.SecurityManagement import newSecurityManager
         newSecurityManager(None, DummyUser('a_user'))
         context = DummyContext()
@@ -139,7 +130,7 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         request = DummyRequest()
         response = request.response = DummyResponse()
         view = self._makeView(context, request)
-        vptf = self._makeOne('pages/dirpage1.pt')
+        vptf = self._makeOne('templates/dirpage1.pt')
         body = vptf(view)
         self.assertEqual(body, DIRPAGE1)
         self.assertEqual(response._headers['Content-Type'], 'text/html')
@@ -148,27 +139,30 @@ class ViewPageTemplateFileTests(unittest.TestCase):
         context = DummyContext()
         request = DummyRequest()
         response = request.response = DummyResponse(
-                                        {'Content-Type': 'text/xhtml'})
+            {'Content-Type': 'text/xhtml'})
         view = self._makeView(context, request)
-        vptf = self._makeOne('pages/dirpage1.pt')
-        body = vptf(view)
+        vptf = self._makeOne('templates/dirpage1.pt')
+        vptf(view)
         self.assertEqual(response._headers['Content-Type'], 'text/xhtml')
 
     def test___get___(self):
         from Products.Five.browser.pagetemplatefile import BoundPageTemplate
-        template = self._makeOne('pages/dirpage1.pt')
+        template = self._makeOne('templates/dirpage1.pt')
+
         class Foo:
             def __init__(self, context, request):
                 self.context = context
                 self.request = request
             bar = template
+
         context = DummyContext()
         request = DummyRequest()
         foo = Foo(context, request)
         bound = foo.bar
-        self.failUnless(isinstance(bound, BoundPageTemplate))
-        self.failUnless(bound.im_func is template)
-        self.failUnless(bound.im_self is foo)
+        self.assertIsInstance(bound, BoundPageTemplate)
+        self.assertTrue(bound.__func__ is template)
+        self.assertTrue(bound.__self__ is foo)
+
 
 class ViewMapperTests(unittest.TestCase):
 
@@ -192,21 +186,25 @@ class ViewMapperTests(unittest.TestCase):
         return self._getTargetClass()(ob, request)
 
     def test___getitem___miss(self):
-        from zope.component import ComponentLookupError
+        from zope.interface.interfaces import ComponentLookupError
         mapper = self._makeOne()
         self.assertRaises(ComponentLookupError, mapper.__getitem__, 'nonesuch')
 
     def test___getitem___hit(self):
-        from zope.interface import Interface
         from zope.component import provideAdapter
+        from zope.interface import Interface
+
         def _adapt(context, request):
             return self
+
         provideAdapter(_adapt, (None, None), Interface, name='test')
         mapper = self._makeOne()
-        self.failUnless(mapper['test'] is self)
+        self.assertTrue(mapper['test'] is self)
+
 
 _marker = object()
 
+
 class BoundPageTemplateTests(unittest.TestCase):
 
     def _getTargetClass(self):
@@ -224,9 +222,9 @@ class BoundPageTemplateTests(unittest.TestCase):
         pt = DummyTemplate({'foo': 'bar'})
         ob = DummyContext()
         bpt = self._makeOne(pt, ob)
-        self.failUnless(bpt.im_func is pt)
-        self.failUnless(bpt.im_self is ob)
-        self.failUnless(bpt.__parent__ is ob)
+        self.assertTrue(bpt.__func__ is pt)
+        self.assertTrue(bpt.__self__ is ob)
+        self.assertTrue(bpt.__parent__ is ob)
         self.assertEqual(bpt.macros['foo'], 'bar')
         self.assertEqual(bpt.filename, 'dummy.pt')
 
@@ -239,7 +237,7 @@ class BoundPageTemplateTests(unittest.TestCase):
         else:
             self.fail('Attribute assigned')
 
-    def test___call___w_real_im_self_no_args_no_kw(self):
+    def test___call___w_real_self_no_args_no_kw(self):
         pt = DummyTemplate()
         ob = DummyContext()
         bpt = self._makeOne(pt, ob)
@@ -247,7 +245,7 @@ class BoundPageTemplateTests(unittest.TestCase):
         self.assertEqual(rendered, '<h1>Dummy</h1>')
         self.assertEqual(pt._called_with, (ob, (), {}))
 
-    def test___call___w_real_im_self_w_args_w_kw(self):
+    def test___call___w_real_self_w_args_w_kw(self):
         pt = DummyTemplate()
         ob = DummyContext()
         bpt = self._makeOne(pt, ob)
@@ -255,25 +253,29 @@ class BoundPageTemplateTests(unittest.TestCase):
         self.assertEqual(rendered, '<h1>Dummy</h1>')
         self.assertEqual(pt._called_with, (ob, ('abc',), {'foo': 'bar'}))
 
-    def test___call___wo_real_im_self_w_args_w_kw(self):
+    def test___call___wo_real_self_w_args_w_kw(self):
         pt = DummyTemplate()
         bpt = self._makeOne(pt, None)
         rendered = bpt('abc', 'def', foo='bar')
         self.assertEqual(rendered, '<h1>Dummy</h1>')
         self.assertEqual(pt._called_with, ('abc', ('def',), {'foo': 'bar'}))
 
+
 DIRPAGE1 = """\
 <html>
 <p>This is page 1</p>
 </html>
 """
 
+
 class DummyContext:
     pass
 
+
 class DummyRequest:
     debug = object()
 
+
 class DummyResponse:
     def __init__(self, headers=None):
         if headers is None:
@@ -286,30 +288,31 @@ class DummyResponse:
     def setHeader(self, name, value):
         self._headers[name] = value
 
+
 class DummyTemplate:
     filename = 'dummy.pt'
+
     def __init__(self, macros=None):
         if macros is None:
             macros = {}
         self.macros = macros
-    def __call__(self, im_self, *args, **kw):
-        self._called_with = (im_self, args, kw)
+
+    def __call__(self, __self__, *args, **kw):
+        self._called_with = (__self__, args, kw)
         return '<h1>Dummy</h1>'
 
+
 class DummyView:
+
     def __init__(self, context, request):
         self.context = context
         self.request = request
 
+
 class DummyUser:
+
     def __init__(self, name):
         self._name = name
+
     def getId(self):
         return self._name
-
-def test_suite():
-    return unittest.TestSuite((
-        unittest.makeSuite(ViewPageTemplateFileTests),
-        unittest.makeSuite(ViewMapperTests),
-        unittest.makeSuite(BoundPageTemplateTests),
-    ))
