@@ -11,21 +11,13 @@
 #
 ##############################################################################
 
+import html
 import re
 
-import six
-from six import binary_type
-from six import text_type
-
 from DateTime import DateTime
 from DateTime.interfaces import SyntaxError
 
 
-try:
-    from html import escape
-except ImportError:  # PY2
-    from cgi import escape
-
 # This may get overwritten during configuration
 default_encoding = 'utf-8'
 
@@ -37,9 +29,7 @@ def field2string(v):
     """
     if hasattr(v, 'read'):
         return v.read()
-    elif six.PY2 and isinstance(v, text_type):
-        return v.encode(default_encoding)
-    elif six.PY3 and isinstance(v, binary_type):
+    elif isinstance(v, bytes):
         return v.decode(default_encoding)
     else:
         return str(v)
@@ -49,7 +39,7 @@ def field2bytes(v):
     # Converts value to bytes.
     if hasattr(v, 'read'):
         return v.read()
-    elif isinstance(v, text_type):
+    elif isinstance(v, str):
         return v.encode(default_encoding)
     else:
         return bytes(v)
@@ -93,7 +83,7 @@ def field2int(v):
             return int(v)
         except ValueError:
             raise ValueError(
-                "An integer was expected in the value %r" % escape(
+                "An integer was expected in the value %r" % html.escape(
                     v, quote=True
                 )
             )
@@ -110,7 +100,7 @@ def field2float(v):
         except ValueError:
             raise ValueError(
                 "A floating-point number was expected in the value %r" %
-                escape(v, True)
+                html.escape(v, True)
             )
     raise ValueError(
         'Empty entry when <strong>floating-point number</strong> expected')
@@ -128,8 +118,9 @@ def field2long(v):
             return int(v)
         except ValueError:
             raise ValueError(
-                "A long integer was expected in the value %r" % escape(v, True)
-            )
+                "A long integer was expected in the value %r" %
+                html.escape(
+                    v, True))
     raise ValueError('Empty entry when <strong>integer</strong> expected')
 
 
@@ -152,7 +143,7 @@ def field2date(v):
     try:
         v = DateTime(v)
     except SyntaxError:
-        raise SyntaxError("Invalid DateTime " + escape(repr(v), True))
+        raise SyntaxError("Invalid DateTime " + html.escape(repr(v), True))
     return v
 
 
@@ -161,7 +152,7 @@ def field2date_international(v):
     try:
         v = DateTime(v, datefmt="international")
     except SyntaxError:
-        raise SyntaxError("Invalid DateTime " + escape(repr(v)))
+        raise SyntaxError("Invalid DateTime " + html.escape(repr(v)))
     return v
 
 
@@ -171,7 +162,7 @@ def field2boolean(v):
     return bool(v)
 
 
-class _unicode_converter(object):
+class _unicode_converter:
 
     def __call__(self, v):
         # Convert a regular python string. This probably doesn't do
@@ -183,7 +174,7 @@ class _unicode_converter(object):
         #       <input name="description:ustring" .....
         if hasattr(v, 'read'):
             v = v.read()
-        v = text_type(v)
+        v = str(v)
         return self.convert_unicode(v)
 
     def convert_unicode(self, v):
@@ -208,21 +199,21 @@ field2utokens = field2utokens()
 
 class field2utext(_unicode_converter):
     def convert_unicode(self, v):
-        if isinstance(v, binary_type):
-            return text_type(field2text(v.encode('utf8')), 'utf8')
+        if isinstance(v, bytes):
+            return str(field2text(v.encode('utf8')), 'utf8')
         return v
 
 
 field2utext = field2utext()
 
 
-class field2ulines(object):
+class field2ulines:
     def __call__(self, v):
         if hasattr(v, 'read'):
             v = v.read()
         if isinstance(v, (list, tuple)):
             return [field2ustring(x) for x in v]
-        v = text_type(v)
+        v = str(v)
         return self.convert_unicode(v)
 
     def convert_unicode(self, v):
