@@ -15,22 +15,17 @@
 """
 
 import codecs
+import html
 import os
 import random
 import re
 import time
 from cgi import FieldStorage
-from warnings import warn
+from copy import deepcopy
+from urllib.parse import unquote
+from urllib.parse import urlparse
 
-from six import PY2
-from six import PY3
-from six import binary_type
-from six import string_types
-from six import text_type
-from six.moves.urllib.parse import unquote
-from six.moves.urllib.parse import urlparse
-
-from AccessControl.tainted import should_be_tainted as base_should_be_tainted
+from AccessControl.tainted import should_be_tainted
 from AccessControl.tainted import taint_string
 from zope.component import queryUtility
 from zope.i18n.interfaces import IUserPreferredLanguages
@@ -49,13 +44,6 @@ from ZPublisher.Converters import get_converter
 from ZPublisher.interfaces import IXmlrpcChecker
 from ZPublisher.utils import basic_auth_decode
 
-from .cookie import getCookieValuePolicy
-
-
-if PY3:
-    from html import escape
-else:
-    from cgi import escape
 
 # This may get overwritten during configuration
 default_encoding = 'utf-8'
@@ -170,9 +158,11 @@ class HTTPRequest(BaseRequest):
     retry_max_count = 0
 
     def supports_retry(self):
-        if self.retry_count < self.retry_max_count:
-            time.sleep(random.uniform(0, 2 ** (self.retry_count)))
-            return 1
+        return self.retry_count < self.retry_max_count
+
+    def delay_retry(self):
+        # Insert a delay before retrying. Moved here from supports_retry.
+        time.sleep(random.uniform(0, 2 ** (self.retry_count)))
 
     def retry(self):
         self.retry_count = self.retry_count + 1
@@ -212,15 +202,15 @@ class HTTPRequest(BaseRequest):
         if (port is None or default_port[protocol] == port):
             host = hostname
         else:
-            host = '{}:{}'.format(hostname, port)
-        server_url = other['SERVER_URL'] = '%s://%s' % (protocol, host)
+            host = f'{hostname}:{port}'
+        server_url = other['SERVER_URL'] = f'{protocol}://{host}'
         self._resetURLS()
         return server_url
 
     def setVirtualRoot(self, path, hard=0):
         """ Treat the current publishing object as a VirtualRoot """
         other = self.other
-        if isinstance(path, string_types):
+        if isinstance(path, str):
             path = path.split('/')
         self._script[:] = list(map(quote, [_p for _p in path if _p]))
         del self._steps[:]
@@ -239,7 +229,7 @@ class HTTPRequest(BaseRequest):
 
     def physicalPathToVirtualPath(self, path):
         """ Remove the path to the VirtualRoot from a physical path """
-        if isinstance(path, string_types):
+        if isinstance(path, str):
             path = path.split('/')
         rpp = self.other.get('VirtualRootPhysicalPath', ('',))
         i = 0
@@ -420,13 +410,13 @@ class HTTPRequest(BaseRequest):
             server_url = server_url[:-1]
 
         if b:
-            self.base = "%s/%s" % (server_url, b)
+            self.base = f"{server_url}/{b}"
         else:
             self.base = server_url
         while script[:1] == '/':
             script = script[1:]
         if script:
-            script = "%s/%s" % (server_url, script)
+            script = f"{server_url}/{script}"
         else:
             script = server_url
         other['URL'] = self.script = script
@@ -442,11 +432,22 @@ class HTTPRequest(BaseRequest):
         # vars with the same name - they are more like default values
         # for names not otherwise specified in the form.
         cookies = {}
+        taintedcookies = {}
         k = get_env('HTTP_COOKIE', '')
         if k:
             parse_cookie(k, cookies)
+            for k, v in cookies.items():
+                istainted = 0
+                if should_be_tainted(k):
+                    k = taint_string(k)
+                    istainted = 1
+                if should_be_tainted(v):
+                    v = taint_string(v)
+                    istainted = 1
+                if istainted:
+                    taintedcookies[k] = v
         self.cookies = cookies
-        self.taintedcookies = taint(cookies)
+        self.taintedcookies = taintedcookies
 
     def processInputs(
             self,
@@ -482,6 +483,7 @@ class HTTPRequest(BaseRequest):
 
         form = self.form
         other = self.other
+        taintedform = self.taintedform
 
         # If 'QUERY_STRING' is not present in environ
         # FieldStorage will try to get it from sys.argv[1]
@@ -491,9 +493,7 @@ class HTTPRequest(BaseRequest):
 
         meth = None
         fs_kw = {}
-        if PY3:
-            # In Python 3 we need the proper encoding to parse the input.
-            fs_kw['encoding'] = self.charset
+        fs_kw['encoding'] = self.charset
 
         fs = ZopeFieldStorage(
             fp=fp, environ=environ, keep_blank_values=1, **fs_kw)
@@ -520,10 +520,12 @@ class HTTPRequest(BaseRequest):
             fslist = fs.list
             tuple_items = {}
             defaults = {}
+            tainteddefaults = {}
             converter = None
 
             for item in fslist:
 
+                isFileUpload = 0
                 key = item.name
                 if key is None:
                     continue
@@ -533,11 +535,15 @@ class HTTPRequest(BaseRequest):
                    hasattr(item, 'headers'):
                     if item.file and item.filename is not None:
                         item = FileUpload(item)
+                        isFileUpload = 1
                     else:
                         item = item.value
 
                 flags = 0
                 character_encoding = ''
+                # Variables for potentially unsafe values.
+                tainted = None
+                converter_type = None
 
                 # Loop through the different types and set
                 # the appropriate flags
@@ -562,6 +568,7 @@ class HTTPRequest(BaseRequest):
 
                         if c is not None:
                             converter = c
+                            converter_type = type_name
                             flags = flags | CONVERTED
                         elif type_name == 'list':
                             flags = flags | SEQUENCE
@@ -605,6 +612,11 @@ class HTTPRequest(BaseRequest):
                 if key in isCGI_NAMEs or key.startswith('HTTP_'):
                     continue
 
+                # If the key is tainted, mark it so as well.
+                tainted_key = key
+                if should_be_tainted(key):
+                    tainted_key = taint_string(key)
+
                 if flags:
 
                     # skip over empty fields
@@ -616,6 +628,17 @@ class HTTPRequest(BaseRequest):
                         key = key.split(".")
                         key, attr = ".".join(key[:-1]), key[-1]
 
+                        # Update the tainted_key if necessary
+                        tainted_key = key
+                        if should_be_tainted(key):
+                            tainted_key = taint_string(key)
+
+                        # Attributes cannot hold a <.
+                        if should_be_tainted(attr):
+                            raise ValueError(
+                                "%s is not a valid record attribute name" %
+                                html.escape(attr, True))
+
                     # defer conversion
                     if flags & CONVERTED:
                         try:
@@ -624,8 +647,8 @@ class HTTPRequest(BaseRequest):
                                 # encoding.  This gets passed to the converter
                                 # either as unicode, if it can handle it, or
                                 # crunched back down to utf-8 if it can not.
-                                if isinstance(item, binary_type):
-                                    item = text_type(item, character_encoding)
+                                if isinstance(item, bytes):
+                                    item = str(item, character_encoding)
                                 if hasattr(converter, 'convert_unicode'):
                                     item = converter.convert_unicode(item)
                                 else:
@@ -634,6 +657,23 @@ class HTTPRequest(BaseRequest):
                             else:
                                 item = converter(item)
 
+                            # Flag potentially unsafe values
+                            if converter_type in ('string', 'required', 'text',
+                                                  'ustring', 'utext'):
+                                if not isFileUpload and \
+                                   should_be_tainted(item):
+                                    tainted = taint_string(item)
+                            elif converter_type in ('tokens', 'lines',
+                                                    'utokens', 'ulines'):
+                                is_tainted = 0
+                                tainted = item[:]
+                                for i in range(len(tainted)):
+                                    if should_be_tainted(tainted[i]):
+                                        is_tainted = 1
+                                        tainted[i] = taint_string(tainted[i])
+                                if not is_tainted:
+                                    tainted = None
+
                         except Exception:
                             if not item and \
                                not (flags & DEFAULT) and \
@@ -643,14 +683,31 @@ class HTTPRequest(BaseRequest):
                                     item = getattr(item, attr)
                                 if flags & RECORDS:
                                     item = getattr(item[-1], attr)
+                                if tainted_key in tainteddefaults:
+                                    tainted = tainteddefaults[tainted_key]
+                                    if flags & RECORD:
+                                        tainted = getattr(tainted, attr)
+                                    if flags & RECORDS:
+                                        tainted = getattr(tainted[-1], attr)
                             else:
                                 raise
 
+                    elif not isFileUpload and should_be_tainted(item):
+                        # Flag potentially unsafe values
+                        tainted = taint_string(item)
+
+                    # If the key is tainted, we need to store stuff in the
+                    # tainted dict as well, even if the value is safe.
+                    if should_be_tainted(tainted_key) and tainted is None:
+                        tainted = item
+
                     # Determine which dictionary to use
                     if flags & DEFAULT:
                         mapping_object = defaults
+                        tainted_mapping = tainteddefaults
                     else:
                         mapping_object = form
+                        tainted_mapping = taintedform
 
                     # Insert in dictionary
                     if key in mapping_object:
@@ -659,6 +716,49 @@ class HTTPRequest(BaseRequest):
                             # in the list. reclist is mutable.
                             reclist = mapping_object[key]
                             x = reclist[-1]
+
+                            if tainted:
+                                # Store a tainted copy as well
+                                if tainted_key not in tainted_mapping:
+                                    tainted_mapping[tainted_key] = deepcopy(
+                                        reclist)
+                                treclist = tainted_mapping[tainted_key]
+                                lastrecord = treclist[-1]
+
+                                if not hasattr(lastrecord, attr):
+                                    if flags & SEQUENCE:
+                                        tainted = [tainted]
+                                    setattr(lastrecord, attr, tainted)
+                                else:
+                                    if flags & SEQUENCE:
+                                        getattr(
+                                            lastrecord, attr).append(tainted)
+                                    else:
+                                        newrec = record()
+                                        setattr(newrec, attr, tainted)
+                                        treclist.append(newrec)
+
+                            elif tainted_key in tainted_mapping:
+                                # If we already put a tainted value into this
+                                # recordset, we need to make sure the whole
+                                # recordset is built.
+                                treclist = tainted_mapping[tainted_key]
+                                lastrecord = treclist[-1]
+                                copyitem = item
+
+                                if not hasattr(lastrecord, attr):
+                                    if flags & SEQUENCE:
+                                        copyitem = [copyitem]
+                                    setattr(lastrecord, attr, copyitem)
+                                else:
+                                    if flags & SEQUENCE:
+                                        getattr(
+                                            lastrecord, attr).append(copyitem)
+                                    else:
+                                        newrec = record()
+                                        setattr(newrec, attr, copyitem)
+                                        treclist.append(newrec)
+
                             if not hasattr(x, attr):
                                 # If the attribute does not
                                 # exist, set it
@@ -695,9 +795,57 @@ class HTTPRequest(BaseRequest):
                                 # it is not a sequence so
                                 # set the attribute
                                 setattr(b, attr, item)
+
+                            # Store a tainted copy as well if necessary
+                            if tainted:
+                                if tainted_key not in tainted_mapping:
+                                    tainted_mapping[tainted_key] = deepcopy(
+                                        mapping_object[key])
+                                b = tainted_mapping[tainted_key]
+                                if flags & SEQUENCE:
+                                    seq = getattr(b, attr, [])
+                                    seq.append(tainted)
+                                    setattr(b, attr, seq)
+                                else:
+                                    setattr(b, attr, tainted)
+
+                            elif tainted_key in tainted_mapping:
+                                # If we already put a tainted value into this
+                                # record, we need to make sure the whole record
+                                # is built.
+                                b = tainted_mapping[tainted_key]
+                                if flags & SEQUENCE:
+                                    seq = getattr(b, attr, [])
+                                    seq.append(item)
+                                    setattr(b, attr, seq)
+                                else:
+                                    setattr(b, attr, item)
+
                         else:
                             # it is not a record or list of records
                             found = mapping_object[key]
+
+                            if tainted:
+                                # Store a tainted version if necessary
+                                if tainted_key not in tainted_mapping:
+                                    copied = deepcopy(found)
+                                    if isinstance(copied, list):
+                                        tainted_mapping[tainted_key] = copied
+                                    else:
+                                        tainted_mapping[tainted_key] = [copied]
+                                tainted_mapping[tainted_key].append(tainted)
+
+                            elif tainted_key in tainted_mapping:
+                                # We may already have encountered a tainted
+                                # value for this key, and the tainted_mapping
+                                # needs to hold all the values.
+                                tfound = tainted_mapping[tainted_key]
+                                if isinstance(tfound, list):
+                                    tainted_mapping[tainted_key].append(item)
+                                else:
+                                    tainted_mapping[tainted_key] = [tfound,
+                                                                    item]
+
                             if isinstance(found, list):
                                 found.append(item)
                             else:
@@ -713,6 +861,15 @@ class HTTPRequest(BaseRequest):
                                 item = [item]
                             setattr(a, attr, item)
                             mapping_object[key] = [a]
+
+                            if tainted:
+                                # Store a tainted copy if necessary
+                                a = record()
+                                if flags & SEQUENCE:
+                                    tainted = [tainted]
+                                setattr(a, attr, tainted)
+                                tainted_mapping[tainted_key] = [a]
+
                         elif flags & RECORD:
                             # Create a new record, set its attribute
                             # and put it in the dictionary
@@ -720,20 +877,63 @@ class HTTPRequest(BaseRequest):
                                 item = [item]
                             r = mapping_object[key] = record()
                             setattr(r, attr, item)
+
+                            if tainted:
+                                # Store a tainted copy if necessary
+                                if flags & SEQUENCE:
+                                    tainted = [tainted]
+                                r = tainted_mapping[tainted_key] = record()
+                                setattr(r, attr, tainted)
                         else:
                             # it is not a record or list of records
                             if flags & SEQUENCE:
                                 item = [item]
                             mapping_object[key] = item
 
+                            if tainted:
+                                # Store a tainted copy if necessary
+                                if flags & SEQUENCE:
+                                    tainted = [tainted]
+                                tainted_mapping[tainted_key] = tainted
+
                 else:
                     # This branch is for case when no type was specified.
                     mapping_object = form
 
+                    if not isFileUpload and should_be_tainted(item):
+                        tainted = taint_string(item)
+                    elif should_be_tainted(key):
+                        tainted = item
+
                     # Insert in dictionary
                     if key in mapping_object:
                         # it is not a record or list of records
                         found = mapping_object[key]
+
+                        if tainted:
+                            # Store a tainted version if necessary
+                            if tainted_key not in taintedform:
+                                copied = deepcopy(found)
+                                if isinstance(copied, list):
+                                    taintedform[tainted_key] = copied
+                                else:
+                                    taintedform[tainted_key] = [copied]
+                            elif not isinstance(
+                                    taintedform[tainted_key], list):
+                                taintedform[tainted_key] = [
+                                    taintedform[tainted_key]]
+                            taintedform[tainted_key].append(tainted)
+
+                        elif tainted_key in taintedform:
+                            # We may already have encountered a tainted value
+                            # for this key, and the taintedform needs to hold
+                            # all the values.
+                            tfound = taintedform[tainted_key]
+                            if isinstance(tfound, list):
+                                taintedform[tainted_key].append(item)
+                            else:
+                                taintedform[tainted_key] = [tfound, item]
+
                         if isinstance(found, list):
                             found.append(item)
                         else:
@@ -741,20 +941,54 @@ class HTTPRequest(BaseRequest):
                             mapping_object[key] = found
                     else:
                         mapping_object[key] = item
+                        if tainted:
+                            taintedform[tainted_key] = tainted
 
             # insert defaults into form dictionary
             if defaults:
                 for key, value in defaults.items():
+                    tainted_key = key
+                    if should_be_tainted(key):
+                        tainted_key = taint_string(key)
+
                     if key not in form:
                         # if the form does not have the key,
                         # set the default
                         form[key] = value
+
+                        if tainted_key in tainteddefaults:
+                            taintedform[tainted_key] = \
+                                tainteddefaults[tainted_key]
                     else:
                         # The form has the key
+                        tdefault = tainteddefaults.get(tainted_key, value)
                         if isinstance(value, record):
                             # if the key is mapped to a record, get the
                             # record
                             r = form[key]
+
+                            # First deal with tainted defaults.
+                            if tainted_key in taintedform:
+                                tainted = taintedform[tainted_key]
+                                for k, v in tdefault.__dict__.items():
+                                    if not hasattr(tainted, k):
+                                        setattr(tainted, k, v)
+
+                            elif tainted_key in tainteddefaults:
+                                # Find out if any of the tainted default
+                                # attributes needs to be copied over.
+                                missesdefault = 0
+                                for k, v in tdefault.__dict__.items():
+                                    if not hasattr(r, k):
+                                        missesdefault = 1
+                                        break
+                                if missesdefault:
+                                    tainted = deepcopy(r)
+                                    for k, v in tdefault.__dict__.items():
+                                        if not hasattr(tainted, k):
+                                            setattr(tainted, k, v)
+                                    taintedform[tainted_key] = tainted
+
                             for k, v in value.__dict__.items():
                                 # loop through the attributes and value
                                 # in the default dictionary
@@ -769,6 +1003,56 @@ class HTTPRequest(BaseRequest):
                             val = form[key]
                             if not isinstance(val, list):
                                 val = [val]
+
+                            # First deal with tainted copies
+                            if tainted_key in taintedform:
+                                tainted = taintedform[tainted_key]
+                                if not isinstance(tainted, list):
+                                    tainted = [tainted]
+                                for defitem in tdefault:
+                                    if isinstance(defitem, record):
+                                        for k, v in defitem.__dict__.items():
+                                            for origitem in tainted:
+                                                if not hasattr(origitem, k):
+                                                    setattr(origitem, k, v)
+                                    else:
+                                        if defitem not in tainted:
+                                            tainted.append(defitem)
+                                taintedform[tainted_key] = tainted
+
+                            elif tainted_key in tainteddefaults:
+                                missesdefault = 0
+                                for defitem in tdefault:
+                                    if isinstance(defitem, record):
+                                        try:
+                                            for k, v in \
+                                                    defitem.__dict__.items():
+                                                for origitem in val:
+                                                    if not hasattr(
+                                                            origitem, k):
+                                                        missesdefault = 1
+                                                        raise NestedLoopExit
+                                        except NestedLoopExit:
+                                            break
+                                    else:
+                                        if defitem not in val:
+                                            missesdefault = 1
+                                            break
+                                if missesdefault:
+                                    tainted = deepcopy(val)
+                                    for defitem in tdefault:
+                                        if isinstance(defitem, record):
+                                            for k, v in (
+                                                    defitem.__dict__.items()):
+                                                for origitem in tainted:
+                                                    if not hasattr(
+                                                            origitem, k):
+                                                        setattr(origitem, k, v)
+                                        else:
+                                            if defitem not in tainted:
+                                                tainted.append(defitem)
+                                    taintedform[tainted_key] = tainted
+
                             for x in value:
                                 # for each x in the list
                                 if isinstance(x, record):
@@ -815,6 +1099,9 @@ class HTTPRequest(BaseRequest):
                     attr = new
                     if k in form:
                         # If the form has the split key get its value
+                        tainted_split_key = k
+                        if should_be_tainted(k):
+                            tainted_split_key = taint_string(k)
                         item = form[k]
                         if isinstance(item, record):
                             # if the value is mapped to a record, check if it
@@ -832,8 +1119,24 @@ class HTTPRequest(BaseRequest):
                                     # convert it to a tuple and set it
                                     value = tuple(getattr(x, attr))
                                     setattr(x, attr, value)
+
+                        # Do the same for the tainted counterpart
+                        if tainted_split_key in taintedform:
+                            tainted = taintedform[tainted_split_key]
+                            if isinstance(item, record):
+                                seq = tuple(getattr(tainted, attr))
+                                setattr(tainted, attr, seq)
+                            else:
+                                for trec in tainted:
+                                    if hasattr(trec, attr):
+                                        seq = getattr(trec, attr)
+                                        seq = tuple(seq)
+                                        setattr(trec, attr, seq)
                     else:
                         # the form does not have the split key
+                        tainted_key = key
+                        if should_be_tainted(key):
+                            tainted_key = taint_string(key)
                         if key in form:
                             # if it has the original key, get the item
                             # convert it to a tuple
@@ -841,7 +1144,9 @@ class HTTPRequest(BaseRequest):
                             item = tuple(form[key])
                             form[key] = item
 
-            self.taintedform = taint(self.form)
+                        if tainted_key in taintedform:
+                            tainted = tuple(taintedform[tainted_key])
+                            taintedform[tainted_key] = tainted
 
         if meth:
             if 'PATH_INFO' in environ:
@@ -850,19 +1155,9 @@ class HTTPRequest(BaseRequest):
                     path = path[:-1]
             else:
                 path = ''
-            other['PATH_INFO'] = "%s/%s" % (path, meth)
+            other['PATH_INFO'] = f"{path}/{meth}"
             self._hacked_path = 1
 
-    def postProcessInputs(self):
-        """Process the values in request.form to decode strings to unicode.
-        """
-        warn(u'postProcessInputs() is deprecated and will be removed in Zope '
-             u'5.0. If your view implements IBrowserPage, similar processing '
-             u'is now executed automatically.',
-             DeprecationWarning, stacklevel=2)
-        for name, value in self.form.items():
-            self.form[name] = _decode(value, default_encoding)
-
     def resolve_url(self, url):
         # Attempt to resolve a url into an object in the Zope
         # namespace. The url must be a fully-qualified url. The
@@ -1164,29 +1459,33 @@ class HTTPRequest(BaseRequest):
         result = "<h3>form</h3><table>"
         row = '<tr valign="top" align="left"><th>%s</th><td>%s</td></tr>'
         for k, v in _filterPasswordFields(self.form.items()):
-            result = result + row % (escape(k, False), escape(repr(v), False))
+            result = result + row % (
+                html.escape(k, False), html.escape(repr(v), False))
         result = result + "</table><h3>cookies</h3><table>"
         for k, v in _filterPasswordFields(self.cookies.items()):
-            result = result + row % (escape(k, False), escape(repr(v), False))
+            result = result + row % (
+                html.escape(k, False), html.escape(repr(v), False))
         result = result + "</table><h3>lazy items</h3><table>"
         for k, v in _filterPasswordFields(self._lazies.items()):
-            result = result + row % (escape(k, False), escape(repr(v), False))
+            result = result + row % (
+                html.escape(k, False), html.escape(repr(v), False))
         result = result + "</table><h3>other</h3><table>"
         for k, v in _filterPasswordFields(self.other.items()):
             if k in ('PARENTS', 'RESPONSE'):
                 continue
-            result = result + row % (escape(k, False), escape(repr(v), False))
+            result = result + row % (
+                html.escape(k, False), html.escape(repr(v), False))
 
         for n in "0123456789":
             key = "URL%s" % n
             try:
-                result = result + row % (key, escape(self[key], False))
+                result = result + row % (key, html.escape(self[key], False))
             except KeyError:
                 pass
         for n in "0123456789":
             key = "BASE%s" % n
             try:
-                result = result + row % (key, escape(self[key], False))
+                result = result + row % (key, html.escape(self[key], False))
             except KeyError:
                 pass
 
@@ -1194,11 +1493,11 @@ class HTTPRequest(BaseRequest):
         for k, v in self.environ.items():
             if k not in hide_key:
                 result = result + row % (
-                    escape(k, False), escape(repr(v), False))
+                    html.escape(k, False), html.escape(repr(v), False))
         return result + "</table>"
 
     def __repr__(self):
-        return "<%s, URL=%s>" % (self.__class__.__name__, self.get('URL'))
+        return "<{}, URL={}>".format(self.__class__.__name__, self.get('URL'))
 
     def text(self):
         result = "FORM\n\n"
@@ -1263,7 +1562,7 @@ class WSGIRequest(HTTPRequest):
     pass
 
 
-class TaintRequestWrapper(object):
+class TaintRequestWrapper:
 
     def __init__(self, req):
         self._req = req
@@ -1294,7 +1593,7 @@ class TaintRequestWrapper(object):
         return TaintMethodWrapper(self._req.keys)(*args, **kw)
 
 
-class TaintMethodWrapper(object):
+class TaintMethodWrapper:
 
     def __init__(self, method):
         self._method = method
@@ -1343,7 +1642,7 @@ class ZopeFieldStorage(FieldStorage):
 
 
 # Original version: zope.publisher.browser.FileUpload
-class FileUpload(object):
+class FileUpload:
     '''File upload objects
 
     File upload objects are used to represent file-uploaded data.
@@ -1397,16 +1696,6 @@ class FileUpload(object):
     def __next__(self):
         return self.file.__next__()
 
-    if PY2:
-        def __nonzero__(self):
-            return self.__bool__()
-
-        def next(self):
-            return self.file.next()
-
-        def xreadlines(self):
-            return self
-
 
 QPARMRE = re.compile(
     '([\x00- ]*([^\x00- ;,="]+)="([^"]*)"([\x00- ]*[;,])?[\x00- ]*)')
@@ -1453,12 +1742,12 @@ def parse_cookie(text,
                 return result
 
     if name not in result:
-        result[name] = getCookieValuePolicy().load(name, value)
+        result[name] = unquote(value)
 
     return parse_cookie(text[c_len:], result)
 
 
-class record(object):
+class record:
 
     # Allow access to record methods and values from DTML
     __allow_access_to_unprotected_subobjects__ = 1
@@ -1492,7 +1781,7 @@ class record(object):
     def __repr__(self):
         # return repr( self.__dict__ )
         return '{%s}' % ', '.join(
-            "'%s': %s" % (item[0], repr(item[1])) for item in
+            "'{}': {!r}".format(*item) for item in
             sorted(self.__dict__.items()))
 
     def __eq__(self, other):
@@ -1516,80 +1805,6 @@ def _filterPasswordFields(items):
     return result
 
 
-def _decode(value, charset):
-    """Recursively look for string values and decode.
-    """
-    if isinstance(value, list):
-        return [_decode(v, charset) for v in value]
-    elif isinstance(value, tuple):
-        return tuple(_decode(v, charset) for v in value)
-    elif isinstance(value, dict):
-        return dict((k, _decode(v, charset)) for k, v in value.items())
-    elif isinstance(value, binary_type):
-        return text_type(value, charset, 'replace')
-    return value
-
-
 def use_builtin_xmlrpc(request):
     checker = queryUtility(IXmlrpcChecker)
     return checker is None or checker(request)
-
-
-def taint(d):
-    """return as ``dict`` the items from *d* which require tainting.
-
-    *d* must be a ``dict`` with ``str`` keys and values recursively
-    build from elementary values, ``list``, ``tuple``, ``record`` and
-    ``dict``.
-    """
-    def should_taint(v):
-        """check whether *v* needs tainting."""
-        if isinstance(v, (list, tuple)):
-            return any(should_taint(x) for x in v)
-        if isinstance(v, (record, dict)):
-            for k in v:
-                if should_taint(k):
-                    return True
-                if should_taint(v[k]):
-                    return True
-        return should_be_tainted(v)
-
-    def _taint(v):
-        """return a copy of *v* with tainted replacements.
-
-        In the copy, each ``str`` which requires tainting
-        is replaced by the corresponding ``taint_string``.
-        """
-        __traceback_info__ = v
-        if isinstance(v, (binary_type, text_type)) and should_be_tainted(v):
-            return taint_string(v)
-        if isinstance(v, (list, tuple)):
-            return v.__class__(_taint(x) for x in v)
-        if isinstance(v, record):
-            rn = record()
-            for k in v:
-                __traceback_info__ = v, k
-                if should_be_tainted(k):
-                    raise ValueError("Cannot taint `record` attribute names")
-                setattr(rn, k, _taint(v[k]))
-            return rn
-        if isinstance(v, dict):
-            return v.__class__((_taint(k), _taint(v[k])) for k in v)
-        return v
-    td = {}
-    for k in d:
-        v = d[k]
-        if should_taint(k) or should_taint(v):
-            td[_taint(k)] = _taint(v)
-    return td
-
-
-def should_be_tainted(v):
-    """Work around ``AccessControl`` weakness."""
-    if isinstance(v, FileUpload):
-        # `base_should_be_tainted` would read `v` as a side effect
-        return False
-    try:
-        return base_should_be_tainted(v)
-    except Exception:
-        return False
