@@ -12,23 +12,21 @@
 ##############################################################################
 """ CGI Response Output formatter
 """
+import html
 import os
 import re
 import struct
 import sys
 import time
 import zlib
+from email.header import Header
+from email.message import _parseparam
+from email.utils import encode_rfc2231
 from io import BytesIO
-
-from six import PY2
-from six import PY3
-from six import binary_type
-from six import class_types
-from six import reraise
-from six import text_type
-from six.moves.urllib.parse import quote
-from six.moves.urllib.parse import urlparse
-from six.moves.urllib.parse import urlunparse
+from io import IOBase
+from urllib.parse import quote
+from urllib.parse import urlparse
+from urllib.parse import urlunparse
 
 from zExceptions import BadRequest
 from zExceptions import HTTPRedirection
@@ -45,16 +43,6 @@ from ZPublisher.Iterators import IStreamIterator
 from ZPublisher.Iterators import IUnboundStreamIterator
 
 
-try:
-    from html import escape
-except ImportError:  # PY2
-    from cgi import escape
-
-if sys.version_info >= (3, ):
-    from io import IOBase
-else:
-    IOBase = file  # NOQA
-
 # This may get overwritten during configuration
 default_encoding = 'utf-8'
 
@@ -81,7 +69,7 @@ status_codes['resourcelockederror'] = 423
 
 start_of_header_search = re.compile('(<head[^>]*>)', re.IGNORECASE).search
 base_re_search = re.compile('(<base.*?>)', re.I).search
-bogus_str_search = re.compile(b" [a-fA-F0-9]+>$").search
+bogus_str_search = re.compile(b" 0x[a-fA-F0-9]+>$").search
 charset_re_str = (r'(?:application|text)/[-+0-9a-z]+\s*;\s*'
                   r'charset=([-_0-9a-z]+)(?:(?:\s*;)|\Z)')
 charset_re_match = re.compile(charset_re_str, re.IGNORECASE).match
@@ -109,7 +97,13 @@ _CRLF = re.compile(r'[\r\n]')
 
 
 def _scrubHeader(name, value):
-    return ''.join(_CRLF.split(str(name))), ''.join(_CRLF.split(str(value)))
+    if isinstance(value, bytes):
+        # handle ``bytes`` values correctly
+        # we assume that the provider knows that HTTP 1.1 stipulates ISO-8859-1
+        value = value.decode('ISO-8859-1')
+    elif not isinstance(value, str):
+        value = str(value)
+    return ''.join(_CRLF.split(str(name))), ''.join(_CRLF.split(value))
 
 
 _NOW = None  # overwrite for testing
@@ -130,6 +124,30 @@ def build_http_date(when):
         WEEKDAYNAME[wd], day, MONTHNAME[month], year, hh, mm, ss)
 
 
+def make_content_disposition(disposition, file_name):
+    """Create HTTP header for downloading a file with a UTF-8 filename.
+
+    See this and related answers: https://stackoverflow.com/a/8996249/2173868.
+    """
+    header = f'{disposition}'
+    try:
+        file_name.encode('us-ascii')
+    except UnicodeEncodeError:
+        # the file cannot be encoded using the `us-ascii` encoding
+        # which is advocated by RFC 7230 - 7237
+        #
+        # a special header has to be crafted
+        # also see https://tools.ietf.org/html/rfc6266#appendix-D
+        encoded_file_name = file_name.encode('us-ascii', errors='ignore')
+        header += f'; filename="{encoded_file_name}"'
+        quoted_file_name = quote(file_name)
+        header += f'; filename*=UTF-8\'\'{quoted_file_name}'
+        return header
+    else:
+        header += f'; filename="{file_name}"'
+        return header
+
+
 class HTTPBaseResponse(BaseResponse):
     """ An object representation of an HTTP response.
 
@@ -207,9 +225,7 @@ class HTTPBaseResponse(BaseResponse):
             status = location.getStatus()
             location = location.headers['Location']
 
-        if PY2 and isinstance(location, text_type):
-            location = location.encode(self.charset)
-        elif PY3 and isinstance(location, binary_type):
+        if isinstance(location, bytes):
             location = location.decode(self.charset)
 
         # To be entirely correct, we must make sure that all non-ASCII
@@ -250,7 +266,7 @@ class HTTPBaseResponse(BaseResponse):
             # It has already been determined.
             return
 
-        if isinstance(status, class_types) and issubclass(status, Exception):
+        if isinstance(status, type) and issubclass(status, Exception):
             status = status.__name__
 
         if isinstance(status, str):
@@ -289,10 +305,6 @@ class HTTPBaseResponse(BaseResponse):
         `value` may be text or bytes. The default encoding of respective python
         version is used.
         """
-        if PY2:
-            name = str(name)
-            value = str(value)
-
         cookies = self.cookies
         if name in cookies:
             cookie = cookies[name]
@@ -316,17 +328,13 @@ class HTTPBaseResponse(BaseResponse):
         `value` may be text or bytes. The default encoding of respective python
         version is used.
         """
-        if PY2:
-            name = str(name)
-            value = str(value)
-
         cookies = self.cookies
         if name in cookies:
             cookie = cookies[name]
         else:
             cookie = cookies[name] = {}
         if 'value' in cookie:
-            cookie['value'] = '%s:%s' % (cookie['value'], value)
+            cookie['value'] = '{}:{}'.format(cookie['value'], value)
         else:
             cookie['value'] = value
 
@@ -343,9 +351,6 @@ class HTTPBaseResponse(BaseResponse):
 
         `name` has to be text in Python 3.
         """
-        if PY2:
-            name = str(name)
-
         d = kw.copy()
         if 'value' in d:
             d.pop('value')
@@ -411,7 +416,7 @@ class HTTPBaseResponse(BaseResponse):
         headers = self.headers
         if name in headers:
             h = headers[name]
-            h = "%s%s%s" % (h, delimiter, value)
+            h = f"{h}{delimiter}{value}"
         else:
             h = value
         self.setHeader(name, h, scrubbed=True)
@@ -457,7 +462,7 @@ class HTTPBaseResponse(BaseResponse):
                 ibase = base_re_search(text)
                 if ibase is None:
                     text = (text[:index] + '\n<base href="'
-                            + escape(self.base, True) + '" />\n'
+                            + html.escape(self.base, True) + '" />\n'
                             + text[index:])
                     self.text = text
                     self.setHeader('content-length', len(self.body))
@@ -519,7 +524,7 @@ class HTTPBaseResponse(BaseResponse):
         if hasattr(body, 'asHTML'):
             body = body.asHTML()
 
-        if isinstance(body, text_type):
+        if isinstance(body, str):
             body = self._encode_unicode(body)
         elif isinstance(body, bytes):
             pass
@@ -527,7 +532,7 @@ class HTTPBaseResponse(BaseResponse):
             try:
                 body = bytes(body)
             except (TypeError, UnicodeError):
-                body = self._encode_unicode(text_type(body))
+                body = self._encode_unicode(str(body))
 
         # At this point body is always binary
         b_len = len(body)
@@ -538,7 +543,7 @@ class HTTPBaseResponse(BaseResponse):
             self.notFoundError(body[1:-1].decode(self.charset))
         else:
             if title:
-                title = text_type(title)
+                title = str(title)
                 if not is_error:
                     self.body = body = self._html(
                         title, body.decode(self.charset)).encode(self.charset)
@@ -552,15 +557,14 @@ class HTTPBaseResponse(BaseResponse):
 
         if content_type is None:
             if self.isHTML(body):
-                content_type = 'text/html; charset=%s' % self.charset
+                content_type = f'text/html; charset={self.charset}'
             else:
-                content_type = 'text/plain; charset=%s' % self.charset
+                content_type = f'text/plain; charset={self.charset}'
             self.setHeader('content-type', content_type)
         else:
             if content_type.startswith('text/') and \
                'charset=' not in content_type:
-                content_type = '%s; charset=%s' % (content_type,
-                                                   self.charset)
+                content_type = f'{content_type}; charset={self.charset}'
                 self.setHeader('content-type', content_type)
 
         self.setHeader('content-length', len(self.body))
@@ -672,21 +676,21 @@ class HTTPBaseResponse(BaseResponse):
             # of name=value pairs may be quoted.
 
             if attrs.get('quoted', True):
-                cookie = '%s="%s"' % (name, quote(attrs['value']))
+                cookie = '{}="{}"'.format(name, quote(attrs['value']))
             else:
-                cookie = '%s=%s' % (name, quote(attrs['value']))
+                cookie = '{}={}'.format(name, quote(attrs['value']))
             for name, v in attrs.items():
                 name = name.lower()
                 if name == 'expires':
-                    cookie = '%s; Expires=%s' % (cookie, v)
+                    cookie = f'{cookie}; Expires={v}'
                 elif name == 'domain':
-                    cookie = '%s; Domain=%s' % (cookie, v)
+                    cookie = f'{cookie}; Domain={v}'
                 elif name == 'path':
-                    cookie = '%s; Path=%s' % (cookie, v)
+                    cookie = f'{cookie}; Path={v}'
                 elif name == 'max_age':
-                    cookie = '%s; Max-Age=%s' % (cookie, v)
+                    cookie = f'{cookie}; Max-Age={v}'
                 elif name == 'comment':
-                    cookie = '%s; Comment=%s' % (cookie, v)
+                    cookie = f'{cookie}; Comment={v}'
                 elif name == 'secure' and v:
                     cookie = '%s; Secure' % cookie
                 # Some browsers recognize this cookie attribute
@@ -698,7 +702,7 @@ class HTTPBaseResponse(BaseResponse):
                 # providing some protection against CSRF attacks
                 # https://tools.ietf.org/html/draft-west-first-party-cookies-07
                 elif name == 'same_site' and v:
-                    cookie = '%s; SameSite=%s' % (cookie, v)
+                    cookie = f'{cookie}; SameSite={v}'
             cookie_list.append(('Set-Cookie', cookie))
 
         # Should really check size of cookies here!
@@ -709,20 +713,24 @@ class HTTPBaseResponse(BaseResponse):
         """ Return a list of (key, value) pairs for our headers.
 
         o Do appropriate case normalization.
+
+        o Encode header values via `header_encoding_registry`
         """
 
         result = [
             ('X-Powered-By', 'Zope (www.zope.org), Python (www.python.org)')
         ]
 
+        encode = header_encoding_registry.encode
         for key, value in self.headers.items():
             if key.lower() == key:
                 # only change non-literal header names
                 key = '-'.join([x.capitalize() for x in key.split('-')])
-            result.append((key, value))
+            result.append((key, encode(key, value)))
 
         result.extend(self._cookie_list())
-        result.extend(self.accumulated_headers)
+        for key, value in self.accumulated_headers:
+            result.append((key, encode(key, value)))
         return result
 
     def _unauthorized(self):
@@ -761,27 +769,9 @@ class HTTPResponse(HTTPBaseResponse):
         chunks.append(body)
         return b'\r\n'.join(chunks)
 
-    if PY2:
-        __str__ = __bytes__
-
-    # The following two methods are part of a private protocol with
-    # ZServer for handling fatal import errors.
-    _shutdown_flag = None
-
-    def _requestShutdown(self, exitCode=0):
-        """ Request that the server shut down with exitCode after fulfilling
-           the current request.
-        """
-        self._shutdown_flag = exitCode
-
-    def _shutdownRequested(self):
-        """ Returns true if this request requested a server shutdown.
-        """
-        return self._shutdown_flag is not None
-
     # deprecated
     def quoteHTML(self, text):
-        return escape(text, 1)
+        return html.escape(text, 1)
 
     def _traceback(self, t, v, tb, as_html=1):
         tb = format_exception(t, v, tb, as_html=as_html)
@@ -818,7 +808,7 @@ class HTTPResponse(HTTPBaseResponse):
             "Resource not found",
             ("Sorry, the requested resource does not exist."
              "<p>Check the URL and try again.</p>"
-             "<p><b>Resource:</b> " + escape(entry) + "</p>")))
+             "<p><b>Resource:</b> " + html.escape(entry) + "</p>")))
 
     # If a resource is forbidden, why reveal that it exists?
     forbiddenError = notFoundError
@@ -826,8 +816,11 @@ class HTTPResponse(HTTPBaseResponse):
     def debugError(self, entry):
         raise NotFound(self._error_html(
             "Debugging Notice",
-            ("Zope has encountered a problem publishing your object.<p>"
-             "\n" + entry + "</p>")))
+            (
+                "Zope has encountered a problem publishing your object. "
+                "<p>%s</p>" % repr(entry)
+            )
+        ))
 
     def badRequestError(self, name):
         self.setStatus(400)
@@ -893,15 +886,15 @@ class HTTPResponse(HTTPBaseResponse):
         if isinstance(b, Exception):
             try:
                 try:
-                    b = text_type(b)
+                    b = str(b)
                 except UnicodeDecodeError:
-                    b = self._encode_unicode(text_type(b)).decode(self.charset)
+                    b = self._encode_unicode(str(b)).decode(self.charset)
             except Exception:
                 b = '<unprintable %s object>' % type(b).__name__
 
         if fatal and t is SystemExit and v.code == 0:
             body = self.setBody(
-                (text_type(t),
+                (str(t),
                  'Zope has exited normally.<p>'
                  + self._traceback(t, v, tb) + '</p>'),
                 is_error=True)
@@ -913,7 +906,7 @@ class HTTPResponse(HTTPBaseResponse):
 
             if match is None:
                 body = self.setBody(
-                    (text_type(t),
+                    (str(t),
                      'Sorry, a site error occurred.<p>'
                      + self._traceback(t, v, tb) + '</p>'),
                     is_error=True)
@@ -926,7 +919,7 @@ class HTTPResponse(HTTPBaseResponse):
                     body = self.setBody(b, is_error=True)
             else:
                 body = self.setBody(
-                    (text_type(t),
+                    (str(t),
                      b + self._traceback(t, '(see above)', tb, 0)),
                     is_error=True)
         del tb
@@ -982,7 +975,7 @@ class WSGIResponse(HTTPBaseResponse):
         exc.detail = (
             'Sorry, the requested resource does not exist.'
             '<p>Check the URL and try again.</p>'
-            '<p><b>Resource:</b> %s</p>' % escape(entry, True))
+            '<p><b>Resource:</b> %s</p>' % html.escape(entry, True))
         raise exc
 
     # If a resource is forbidden, why reveal that it exists?
@@ -993,8 +986,9 @@ class WSGIResponse(HTTPBaseResponse):
         exc = NotFound(entry)
         exc.title = 'Debugging Notice'
         exc.detail = (
-            'Zope has encountered a problem publishing your object.<p>'
-            '\n%s</p>' % entry)
+            "Zope has encountered a problem publishing your object. "
+            "<p>%s</p>" % repr(entry)
+        )
         raise exc
 
     def badRequestError(self, name):
@@ -1035,7 +1029,7 @@ class WSGIResponse(HTTPBaseResponse):
         if issubclass(t, Unauthorized):
             self._unauthorized()
 
-        reraise(t, v, tb)
+        raise v.with_traceback(tb)
 
     def finalize(self):
         # Set 204 (no content) status if 200 and response is empty
@@ -1051,7 +1045,7 @@ class WSGIResponse(HTTPBaseResponse):
         if content_length is None and not self._streaming:
             self.setHeader('content-length', len(self.body))
 
-        return '%s %s' % (self.status, self.errmsg), self.listHeaders()
+        return f'{self.status} {self.errmsg}', self.listHeaders()
 
     def listHeaders(self):
         result = []
@@ -1059,7 +1053,7 @@ class WSGIResponse(HTTPBaseResponse):
             result.append(('Server', self._server_version))
 
         result.append(('Date', build_http_date(_now())))
-        result.extend(super(WSGIResponse, self).listHeaders())
+        result.extend(super().listHeaders())
         return result
 
     def write(self, data):
@@ -1089,13 +1083,13 @@ class WSGIResponse(HTTPBaseResponse):
             self.body = body
         elif IStreamIterator.providedBy(body):
             self.body = body
-            super(WSGIResponse, self).setBody(b'', title, is_error)
+            super().setBody(b'', title, is_error)
         elif IUnboundStreamIterator.providedBy(body):
             self.body = body
             self._streaming = 1
-            super(WSGIResponse, self).setBody(b'', title, is_error)
+            super().setBody(b'', title, is_error)
         else:
-            super(WSGIResponse, self).setBody(body, title, is_error)
+            super().setBody(body, title, is_error)
 
         # Have to apply the lock at the end in case the super class setBody
         # is called, which will observe the lock and do nothing
@@ -1107,3 +1101,126 @@ class WSGIResponse(HTTPBaseResponse):
 
     def __str__(self):
         raise NotImplementedError
+
+
+# HTTP header encoding
+class HeaderEncodingRegistry(dict):
+    """Encode HTTP headers.
+
+    HTTP/1.1 uses `ISO-8859-1` as charset for its headers
+    (the modern spec (RFC 7230-7235) has deprecated non ASCII characters
+    but for the sake of older browsers we still use `ISO-8859-1`).
+    Header values need encoding if they contain characters
+    not expressible in this charset.
+
+    HTTP/1.1 is based on MIME
+    ("Multimedia Internet Mail Extensions" RFC 2045-2049).
+    MIME knows about 2 header encodings:
+     - one for parameter values (RFC 2231)
+     - and one word words as part of text, phrase or comment (RFC 2047)
+    For use with HTTP/1.1 MIME's parameter value encoding (RFC 2231)
+    was specialized and simplified via RFC 5987 and RFC 8187.
+
+    For efficiency reasons and because HTTP is an extensible
+    protocol (an application can use headers not specified
+    by HTTP), we use an encoding registry to guide the header encoding.
+    An application can register an encoding for specific keys and/or
+    a default encoding to be used for keys without specific registration.
+    If there is neither a specific encoding nor a default encoding,
+    a header value remains unencoded.
+    Header values are encoded only if they contain non `ISO-8859-1` characters.
+    """
+
+    def register(self, header, encoder, **kw):
+        """register *encoder* as encoder for header *header*.
+
+        If *encoder* is `None`, this indicates that *header* should not
+        get encoded.
+
+        If *header* is `None`, this indicates that *encoder* is defined
+        as the default encoder.
+
+        When encoding is necessary, *encoder* is called with
+        the header value and the keywords specified by *kw*.
+        """
+        if header is not None:
+            header = header.lower()
+        self[header] = encoder, kw
+
+    def unregister(self, header):
+        """remove any registration for *header*.
+
+        *header* can be either a header name or `None`.
+        In the latter case, a default registration is removed.
+        """
+        if header is not None:
+            header = header.lower()
+        if header in self:
+            del self[header]
+
+    def encode(self, header, value):
+        """encode *value* as specified for *header*.
+
+        encoding takes only place if *value* contains non ISO-8859-1 chars.
+        """
+        if not isinstance(value, str):
+            return value
+        header = header.lower()
+        reg = self.get(header) or self.get(None)
+        if reg is None or reg[0] is None or non_latin_1(value) is None:
+            return value
+        return reg[0](value, **reg[1])
+
+
+non_latin_1 = re.compile(r"[^\x00-\xff]").search
+
+
+def encode_words(value):
+    """RFC 2047 word encoding.
+
+    Note: treats *value* as unstructured data
+    and therefore must not be applied for headers with
+    a structured value (unless the structure is garanteed
+    to only contain ISO-8859-1 chars).
+    """
+    return Header(value, 'utf-8', 1000000).encode()
+
+
+def encode_params(value):
+    """RFC 5987(8187) (specialized from RFC 2231) parameter encoding.
+
+    This encodes parameters as specified by RFC 5987 using
+    fixed `UTF-8` encoding (as required by RFC 8187).
+    However, all parameters with non latin-1 values are
+    automatically transformed and a `*` suffixed parameter is added
+    (RFC 8187 allows this only for parameters explicitly specified
+    to have this behavior).
+
+    Many HTTP headers use `,` separated lists. For simplicity,
+    such headers are not supported (we would need to recognize
+    `,` inside quoted strings as special).
+    """
+    params = []
+    for p in _parseparam(";" + value):
+        p = p.strip()
+        if not p:
+            continue
+        params.append([s.strip() for s in p.split("=", 1)])
+    known_params = {p[0] for p in params}
+    for p in params[:]:
+        if len(p) == 2 and non_latin_1(p[1]):  # need encoding
+            pn = p[0]
+            pnc = pn + "*"
+            pv = p[1]
+            if pnc not in known_params:
+                if pv.startswith('"'):
+                    pv = pv[1:-1]  # remove quotes
+                params.append((pnc, encode_rfc2231(pv, "utf-8", None)))
+            # backward compatibility for clients not understanding RFC 5987
+            p[1] = p[1].encode("iso-8859-1", "replace").decode("iso-8859-1")
+    return "; ".join("=".join(p) for p in params)
+
+
+header_encoding_registry = HeaderEncodingRegistry()
+header_encoding_registry.register("content-type", encode_params)
+header_encoding_registry.register("content-disposition", encode_params)
