@@ -1,5 +1,4 @@
 ##############################################################################
-# coding: utf-8
 #
 # Copyright (c) 2002 Zope Foundation and Contributors.
 #
@@ -17,9 +16,6 @@ import unittest
 from contextlib import contextmanager
 from io import BytesIO
 
-from six import PY2
-
-from AccessControl.tainted import TaintedString
 from AccessControl.tainted import should_be_tainted
 from zExceptions import NotFound
 from zope.component import getGlobalSiteManager
@@ -29,7 +25,6 @@ from zope.i18n.interfaces.locales import ILocale
 from zope.publisher.browser import BrowserLanguages
 from zope.publisher.interfaces.http import IHTTPRequest
 from zope.testing.cleanup import cleanUp
-from ZPublisher.HTTPRequest import FileUpload
 from ZPublisher.HTTPRequest import search_type
 from ZPublisher.interfaces import IXmlrpcChecker
 from ZPublisher.tests.testBaseRequest import TestRequestViewsBase
@@ -37,10 +32,6 @@ from ZPublisher.utils import basic_auth_encode
 from ZPublisher.xmlrpc import is_xmlrpc_response
 
 
-if sys.version_info >= (3, ):
-    unicode = str
-
-
 class RecordTests(unittest.TestCase):
 
     def _makeOne(self):
@@ -84,6 +75,13 @@ class RecordTests(unittest.TestCase):
         rec2.b = 'foo'
         self.assertNotEqual(rec1, rec2)
 
+    def test__str__returns_native_string(self):
+        rec = self._makeOne()
+        rec.a = b'foo'
+        rec.b = 8
+        rec.c = 'bar'
+        self.assertIsInstance(str(rec), str)
+
     def test_str(self):
         rec = self._makeOne()
         rec.a = 1
@@ -98,7 +96,7 @@ class RecordTests(unittest.TestCase):
         self.assertEqual(d, rec.__dict__)
 
 
-class HTTPRequestFactoryMixin(object):
+class HTTPRequestFactoryMixin:
 
     def tearDown(self):
         cleanUp()
@@ -138,7 +136,7 @@ class HTTPRequestFactoryMixin(object):
 class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
 
     def _processInputs(self, inputs):
-        from six.moves.urllib.parse import quote_plus
+        from urllib.parse import quote_plus
 
         # Have the inputs processed, and return a HTTPRequest object
         # holding the result.
@@ -148,7 +146,7 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         query_string = []
         add = query_string.append
         for key, val in inputs:
-            add("%s=%s" % (quote_plus(key), quote_plus(val)))
+            add("{}={}".format(quote_plus(key), quote_plus(val)))
         query_string = '&'.join(query_string)
 
         env = {'SERVER_NAME': 'testingharnas', 'SERVER_PORT': '80'}
@@ -192,7 +190,7 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
                 if rval:
                     retval = 1
 
-        elif type(val) in (str, unicode):
+        elif isinstance(val, str):
             self.assertFalse(
                 should_be_tainted(val),
                 "'%s' is dangerous and should have been tainted." % val)
@@ -315,13 +313,8 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         self._onlyTaintedformHoldsTaintedStrings(req)
 
     def test_processInputs_w_unicode_conversions(self):
-        # This tests native strings, which mean something different
-        # under Python 2 / 3.
-        if PY2:
-            reg_char = '\xc2\xae'
-        else:
-            reg_char = '\xae'
-
+        # This tests native strings.
+        reg_char = '\xae'
         inputs = (('ustring:ustring:utf8', 'test' + reg_char),
                   ('utext:utext:utf8',
                    'test' + reg_char + '\ntest' + reg_char + '\n'),
@@ -338,10 +331,10 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
             formkeys,
             ['nouconverter', 'ulines', 'ustring', 'utext', 'utokens'])
 
-        self.assertEqual(req['ustring'], u'test\u00AE')
-        self.assertEqual(req['utext'], u'test\u00AE\ntest\u00AE\n')
-        self.assertEqual(req['utokens'], [u'test\u00AE', u'test\u00AE'])
-        self.assertEqual(req['ulines'], [u'test\u00AE', u'test\u00AE'])
+        self.assertEqual(req['ustring'], 'test\u00AE')
+        self.assertEqual(req['utext'], 'test\u00AE\ntest\u00AE\n')
+        self.assertEqual(req['utokens'], ['test\u00AE', 'test\u00AE'])
+        self.assertEqual(req['ulines'], ['test\u00AE', 'test\u00AE'])
 
         # expect a utf-8 encoded version
         self.assertEqual(req['nouconverter'], 'test' + reg_char)
@@ -808,34 +801,6 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         self.assertEqual(req.form['foo'], '1')
         self.assertEqual(req.form['bar'], '2')
 
-    def test_postProcessInputs(self):
-        from ZPublisher.HTTPRequest import default_encoding
-
-        _NON_ASCII = u'\xc4\xd6\xdc'
-        req = self._makeOne()
-        req.form = {'foo': _NON_ASCII.encode(default_encoding),
-                    'foo_list': [_NON_ASCII.encode(default_encoding), 'SPAM'],
-                    'foo_tuple': (_NON_ASCII.encode(default_encoding), 'HAM'),
-                    'foo_dict': {'foo': _NON_ASCII, 'bar': 'EGGS'}}
-        req.postProcessInputs()
-        self.assertIsInstance(req.form['foo'], unicode)
-        self.assertEqual(req.form['foo'], _NON_ASCII)
-        self.assertIsInstance(req.form['foo_list'], list)
-        self.assertIsInstance(req.form['foo_list'][0], unicode)
-        self.assertEqual(req.form['foo_list'][0], _NON_ASCII)
-        self.assertIsInstance(req.form['foo_list'][1], unicode)
-        self.assertEqual(req.form['foo_list'][1], u'SPAM')
-        self.assertIsInstance(req.form['foo_tuple'], tuple)
-        self.assertIsInstance(req.form['foo_tuple'][0], unicode)
-        self.assertEqual(req.form['foo_tuple'][0], _NON_ASCII)
-        self.assertIsInstance(req.form['foo_tuple'][1], unicode)
-        self.assertEqual(req.form['foo_tuple'][1], u'HAM')
-        self.assertIsInstance(req.form['foo_dict'], dict)
-        self.assertIsInstance(req.form['foo_dict']['foo'], unicode)
-        self.assertEqual(req.form['foo_dict']['foo'], _NON_ASCII)
-        self.assertIsInstance(req.form['foo_dict']['bar'], unicode)
-        self.assertEqual(req.form['foo_dict']['bar'], u'EGGS')
-
     def test_close_removes_stdin_references(self):
         # Verifies that all references to the input stream go away on
         # request.close().  Otherwise a tempfile may stick around.
@@ -887,6 +852,7 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         self.assertEqual(password_x, password)
 
     def test__authUserPW_with_embedded_colon(self):
+        # http://www.zope.org/Collectors/Zope/2039
         user_id = 'user'
         password = 'embedded:colon'
         auth_header = basic_auth_encode(user_id, password)
@@ -899,19 +865,6 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         self.assertEqual(user_id_x, user_id)
         self.assertEqual(password_x, password)
 
-    def test__authUserPW_non_ascii(self):
-        user_id = 'usèr'
-        password = 'pàssword'
-        auth_header = basic_auth_encode(user_id, password)
-
-        environ = {'HTTP_AUTHORIZATION': auth_header}
-        request = self._makeOne(environ=environ)
-
-        user_id_x, password_x = request._authUserPW()
-
-        self.assertEqual(user_id_x, user_id)
-        self.assertEqual(password_x, password)
-
     def test_debug_not_in_qs_still_gets_attr(self):
         from zope.publisher.base import DebugFlags
 
@@ -1149,7 +1102,7 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         self.assertEqual(clone['PARENTS'], PARENTS[1:])
 
     def test_clone_preserves_response_class(self):
-        class DummyResponse(object):
+        class DummyResponse:
             pass
         environ = self._makePostEnviron()
         request = self._makeOne(None, environ, DummyResponse())
@@ -1179,13 +1132,6 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         self.assertTrue(IFoo.providedBy(clone))
 
     def test_resolve_url_doesnt_send_endrequestevent(self):
-        # The following imports are necessary:
-        #  They happen implicitely in `request.resolve_url`
-        #  They creates `zope.schema` events
-        # Doing them here avoids those unrelated events
-        import OFS.PropertyManager  # noqa: F401
-        import OFS.SimpleItem  # noqa: F401
-        #
         import zope.event
         events = []
         zope.event.subscribers.append(events.append)
@@ -1232,6 +1178,10 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         req._script = ['foo', 'bar']
         self.assertEqual(req.getVirtualRoot(), '/foo/bar')
 
+    def test__str__returns_native_string(self):
+        r = self._makeOne()
+        self.assertIsInstance(str(r), str)
+
     def test___str____password_field(self):
         # It obscures password fields.
         req = self._makeOne()
@@ -1323,19 +1273,6 @@ class HTTPRequestTests(unittest.TestCase, HTTPRequestFactoryMixin):
         req = self._makeOne(environ=env)
         self.assertEqual(req['SERVER_URL'], 'https://myhost')
 
-    def test_issue_1095(self):
-        body = TEST_ISSUE_1095_DATA
-        env = self._makePostEnviron(body)
-        req = self._makeOne(BytesIO(body), env)
-        req.processInputs()
-        r = req["r"]
-        self.assertEqual(len(r), 2)
-        self.assertIsInstance(r[0].x, FileUpload)
-        self.assertIsInstance(r[1].x, str)
-        r = req.taintedform["r"]
-        self.assertIsInstance(r[0].x, FileUpload)
-        self.assertIsInstance(r[1].x, TaintedString)
-
 
 class TestHTTPRequestZope3Views(TestRequestViewsBase):
 
@@ -1416,19 +1353,3 @@ Content-Disposition: form-data; name="largefile"; filename="largefile"
 Content-Type: application/octet-stream
 
 test ''' + (b'test' * 1000) + b'\n\n'
-
-TEST_ISSUE_1095_DATA = b'''
---12345
-Content-Disposition: form-data; name="r.x:records"; filename="fn"
-Content-Type: application/octet-stream
-
-test
-
---12345
-Content-Disposition: form-data; name="r.x:records"
-Content-Type: text/html
-
-<body>abc</body>
-
---12345--
-'''
