@@ -16,27 +16,9 @@
 import io
 import os
 import traceback
-
-from six import PY2
-from six import text_type
-from six.moves import UserDict
+from collections import UserDict
 
 from ZODB.config import ZODBDatabase
-from zope.deferredimport import deprecated
-
-
-# BBB Zope 5.0
-_prefix = 'ZServer.Zope2.Startup.datatypes:'
-deprecated(
-    'Please import from ZServer.Zope2.Startup.datatypes.',
-    cgi_environment=_prefix + 'cgi_environment',
-    LoggerFactory=_prefix + 'LoggerFactory',
-    dns_resolver=_prefix + 'dns_resolver',
-    python_dotted_path=_prefix + 'python_dotted_path',
-    zdaemonEnvironDict=_prefix + 'zdaemonEnvironDict',
-    root_config=_prefix + 'root_config',
-    minimalClassFactory=_prefix + 'minimalClassFactory',
-)
 
 
 def security_policy_implementation(value):
@@ -90,7 +72,7 @@ def importable_name(name):
         IO = io.StringIO()
         traceback.print_exc(file=IO)
         raise ValueError(
-            'The object named by "%s" could not be imported\n%s' % (
+            'The object named by "{}" could not be imported\n{}'.format(
                 name, IO.getvalue()))
 
 
@@ -170,8 +152,6 @@ class ZopeDatabase(ZODBDatabase):
     def computeMountPaths(self):
         mps = []
         for part in self.config.mount_points:
-            if PY2 and isinstance(part, text_type):
-                part = part.encode()
             real_root = None
             if ':' in part:
                 # 'virtual_path:real_path'
@@ -210,9 +190,6 @@ def default_zpublisher_encoding(value):
     # so a module-level call to getConfiguration in any of them
     # results in getting config data structure without the necessary
     # value in it.
-    if PY2:
-        # unicode is not acceptable as encoding in HTTP headers:
-        value = str(value)
     from ZPublisher import Converters
     from ZPublisher import HTTPRequest
     from ZPublisher import HTTPResponse
@@ -224,7 +201,7 @@ def default_zpublisher_encoding(value):
     return value
 
 
-class DBTab(object):
+class DBTab:
     """A Zope database configuration, similar in purpose to /etc/fstab.
     """
 
